@@ -566,18 +566,68 @@ var MeasureText = function(font, text) {
 
 // Functions to download the motif block diagram as a PDF or SVG file.
 function download_PDF_block_diagram() {
-  downloadBlockDiagram(true);
+  downloadBlockDiagram(true, 'bitbucket');
 }
 function download_SVG_block_diagram() {
-  downloadBlockDiagram(false);
+  downloadBlockDiagram(false, 'bitbucket');
+}
+
+// Helper function to create a script element for downloading javascript.
+function createScriptElement(url, file, integrity)
+{
+  console.log('Downloading ' + file + ' from ' + url + '.');
+  const script = document.createElement('script');
+  script.setAttribute('src', url + '/' + file);
+  if (integrity) script.setAttribute('integrity', integrity);
+  script.setAttribute('crossorigin', 'anonymous');
+  script.setAttribute('async', '');
+  document.head.appendChild(script);
 }
 
 // Helper function to download the motif block diagram as a PDF or SVG file.
 var downloadBlockDiagram = function(
+  make_pdf,
+  next_source
+) {
+  var script_file, integrity_key;
+  // Check if necessary javascript has been loaded.
+  if ( (make_pdf && typeof jsPDF === 'undefined') ||
+    (!make_pdf && typeof d3 === 'undefined') ) {
+    if (next_source === 'bitbucket') {
+      if (make_pdf) {
+        script_file = 'jspdf.min.js';
+      } else {
+        script_file = 'd3.v5.min.js';
+      }
+      createScriptElement('https://memesuite.bitbucket.io/javascript', script_file);
+      // Wait 3 seconds and then try to create the diagram.
+      setTimeout(downloadBlockDiagram, 3000, make_pdf, 'cloudflare');
+    } else if (next_source === 'cloudflare') {
+      if (make_pdf) {
+        script_file = 'jspdf/1.5.3/jspdf.min.js';
+        integrity_key = 'sha512-ToRWKKOvhBSS8EtqSflysM/S7v9bB9V0X3B1+E7xo7XZBEZCPL3VX5SFIp8zxY19r7Sz0svqQVbAOx+QcLQSAQ=='
+      } else {
+        script_file = 'd3/5.16.0/d3.min.js';
+        integrity_key = 'sha512-FHsFVKQ/T1KWJDGSbrUhTJyS1ph3eRrxI228ND0EGaEp6v4a/vGwPWd3Dtd/+9cI7ccofZvl/wulICEurHN1pg==';
+      }
+      createScriptElement('https://cdnjs.cloudflare.com/ajax/libs', script_file, integrity_key);
+      // Wait 3 seconds and then try to create the diagram.
+      setTimeout(downloadBlockDiagram, 3000, make_pdf, 'none');
+    } else {
+      // No more sources for javascript.  Call so error message will be shown.
+      downloadBlockDiagramMain(make_pdf);
+    }
+  } else {
+    // Create the diagram.
+    downloadBlockDiagramMain(make_pdf);
+  }
+}
+
+// Main function to download the motif block diagram as a PDF or SVG file.
+var downloadBlockDiagramMain= function(
   make_pdf
 ) {
-
-  // Check that the required javascript was loaded.
+  // Check that necessary javascript was downloaded.
   if ( (make_pdf && typeof jsPDF === 'undefined') ||
     (!make_pdf && typeof d3 === 'undefined') ) {
     var id = make_pdf ? $("pdfButton") : $("svgButton");
