@@ -3,6 +3,7 @@ var have_tissue_panel = (data.options["tissues"] != "");
 var sort_table = {
   "regulatory_link": [
     {"name": "Closest TSS (CT)", "fn": sort_closest_tss, "priority": 1},
+    {"name": "q-value", "fn": sort_qvalue, "show": have_tissue_panel},
     {"name": "CnD p-value", "fn": sort_cnd_pvalue, "show": have_tissue_panel},
     {"name": "Correlation p-value", "fn": sort_corr_pvalue, "show": have_tissue_panel},
     {"name": "Distance p-value", "fn": sort_dist_pvalue},
@@ -316,6 +317,14 @@ function sort_correlation_incr(link1, link2) {
   return sort_cnd_pvalue(link1, link2);
 } // sort_correlation_incr
 
+// Sort by increasing qvalue, then CnD pvalue
+function sort_qvalue(link1, link2) {
+  var diff;
+  diff = link1['qvalue'] - link2['qvalue'];
+  if (diff != 0) return diff;
+  return sort_cnd_pvalue(link1, link2);
+} // sort_cnd_pvalue
+
 // Sort by increasing CnD pvalue, then correlation pvalue
 function sort_cnd_pvalue(link1, link2) {
   var diff;
