@@ -1260,7 +1260,7 @@ ARRAY_T* get_nrdb_frequencies(ALPH_T *alph, ARRAY_T *freqs) {
   // vars
   const PROB_T *nrdb_freqs;
   int i;
-  // FIXME this is not a great implementation but unless we put the frequencies
+  // TODO this is not a great implementation but unless we put the frequencies
   // into the alphabets I'm not sure how to solve it...
   if (alph_is_builtin_dna(alph)) {
     nrdb_freqs = NRDB_DNA;
@@ -1623,7 +1623,7 @@ ARRAY_T* load_markov_model_without_alph(const char *bg_filename, int *order, cha
     die("Unable to open background file \"%s\" for reading.\n", bg_filename);
   }
   // setup symbol map for order 0 bg
-  symbols = rbtree_create(alph_str_cmp, rbtree_strcpy, free, rbtree_dblcpy, free); // TODO FIXME use true alphabet symbol order
+  symbols = rbtree_create(alph_str_cmp, rbtree_strcpy, free, rbtree_dblcpy, free); // TODO use true alphabet symbol order
   // read each entry of length 1
   while (load_markov_model_entry2(bg_filename, fp, line_buf, 100, sym_buf, 100, num_buf, &value)) {
     if (str_len(sym_buf) > 1) break;
@@ -1936,14 +1936,21 @@ void translate_seq(ALPH_T *alph, char *sequence, int flags) {
 /*
  * invcomp_seq
  * Converts a sequence in place to its reverse complement.
+ * Preserve case of input sequence if preserve_case is true
  */
-void invcomp_seq(ALPH_T *alph, char *sequence, long length) {
+void invcomp_seq(ALPH_T *alph, char *sequence, long length, bool preserve_case) {
   char *sl, *sr, tmp;
   sl = sequence; 
   sr = sequence+(length - 1);
   for(; sl <= sr; sl++, sr--) {
     tmp = comp_sym(alph, *sl);
+    if (preserve_case  && *sl >= 'a' && *sl <= 'z') {
+      tmp = tolower(tmp);
+    }
     *sl = comp_sym(alph, *sr);
+    if (preserve_case  && *sr >= 'a' && *sr <= 'z') {
+      *sl = tolower(*sl);
+    }
     *sr = tmp;
   }
 }
@@ -2342,6 +2349,7 @@ ARRAY_T *get_markov_from_sequences(
   argv[argc++] = seqfile;
   tmp_bfile = fasta_get_markov(argc, argv, true);
   back = load_markov_model(alph, order, tmp_bfile);
+  unlink(tmp_bfile);
   
   return(back);
 } // get_markov_from_sequences
