@@ -18,7 +18,10 @@
  * AMA works on DNA data only.
  ********************************************************************/
 
+#ifdef MAIN
 #define DEFINE_GLOBALS
+#endif
+
 #include <assert.h>
 #include <ctype.h>
 #include <errno.h>
@@ -120,8 +123,6 @@ static char *default_output_dirname = "ama_out";  // default output directory na
 static const char *text_filename = "ama.txt";
 static const char *cisml_filename = "ama.xml";
 
-VERBOSE_T verbosity = NORMAL_VERBOSE;
-
 // Structure for tracking ama command line parameters.
 typedef struct options {
   char *command_line;
