@@ -327,8 +327,14 @@ int main(int argc, char *argv[]) {
   }
 
   // Iterate through the BED file
+  int line_no = 0;
   while ((line = getline2(bed_file)) != NULL) {
-    if (line[0] == '#') {
+    line_no++;
+    // Ignore comment lines.
+    if (line[0] == '#' || 
+      !strncmp(line, "track", 5) ||
+      !strncmp(line, "browser", 7)
+    ) {
       myfree(line);
       continue;
     }
@@ -337,9 +343,29 @@ int main(int argc, char *argv[]) {
     if (line[length - 1] == '\n') line[length - 1] = 0;
     STRING_LIST_T* bed_values  = new_string_list_char_split('\t', line);
     int num_fields = get_num_strings(bed_values);
+    // Ignore empty / all-space lines.
+    if (num_fields == 0) {
+      myfree(line);
+      continue;
+    }
+    if (num_fields < 3) {
+      fprintf(error_file, "WARNING: Line number %d has fewer than three fields. Skipping.\n", line_no);
+      continue;
+    }
     char *chrom = get_nth_string(0, bed_values);
+    if (strlen(chrom) == 0) {
+      fprintf(error_file, "WARNING: Line number %d has an empty name field (field 1). Skipping.\n", line_no);
+      continue;
+    }
     long chrom_start = strtol(get_nth_string(1, bed_values), NULL, 10);
+    if (chrom_start == 0 && errno != 0) {
+      fprintf(error_file, "WARNING: Line number %d has a start field that is not a number. Skipping.\n", line_no); 
+    }
     long chrom_end = strtol(get_nth_string(2, bed_values), NULL, 10);
+    if (chrom_end == 0 && errno != 0) {
+      fprintf(error_file, "WARNING: Line number %d has an end field that is not a number. Skipping.\n", line_no); 
+      continue;
+    }
     char *bed_name = get_nth_string(3, bed_values);
     char strand = '\0';
     if (chrom_start < 0) {
