@@ -507,12 +507,12 @@ void print_results(
   // print the sites "making up" the model 
 #ifdef PARALLEL
 #ifdef DEBUG_PARALLEL
-  fprintf(stderr, "%d: at print_print_sites\n", mpMyID()); fflush(stderr);
+  fprintf(stderr, "at print_print_sites\n"); fflush(stderr);
 #endif
 #endif
   if (dataset->n_samples <= dataset->brief) print_sites(dataset, model, consensus, PRINT_FASTA, "", outfile);
 #ifdef DEBUG_PARALLEL
-  fprintf(stderr, "%d: past print_print_sites\n", mpMyID()); fflush(stderr);
+  fprintf(stderr, "past print_print_sites\n"); fflush(stderr);
 #endif
 
   // print the logodds matrix 
@@ -801,7 +801,7 @@ static void print_log_odds(
 
 #ifdef PARALLEL
 #ifdef DEBUG_PARALLEL
-  fprintf(stderr, "%d: at print_print_logodds\n", mpMyID()); fflush(stderr);
+  fprintf(stderr, "at print_print_logodds\n"); fflush(stderr);
 #endif
 #endif
 
@@ -827,7 +827,7 @@ static void print_log_odds(
 
 #ifdef PARALLEL
 #ifdef DEBUG_PARALLEL
-  fprintf(stderr, "%d: leaving print_print_logodds\n", mpMyID()); fflush(stderr);
+  fprintf(stderr, "leaving print_print_logodds\n"); fflush(stderr);
 #endif
 #endif
 } // print_log_odds 
