@@ -537,7 +537,7 @@ int main(int argc, char *argv[])
     int c = 0;
     char* option_name = NULL;
     char* option_value = NULL;
-		const char *  message = NULL;
+		const char* message = NULL;
 
     // Read the next option, and break if we're done.
     c = simple_getopt(&option_name, &option_value, &option_index);
@@ -545,7 +545,7 @@ int main(int argc, char *argv[])
       break;
     } else if (c < 0) {
     	simple_getopterror(&message);
-      die("Error processing command line options (%s)\n", message);
+      die("Error processing command line options: %s\n", message);
     }
 
     if (strcmp(option_name, "seq-reader") == 0) {
