@@ -127,23 +127,25 @@ void init_meme(
 {
   int i, j, len, pos;
   char cc;
-  OBJTYPE objfun = Classic; // type of objective function 
-  TESTTYPE test = No_testtype; // use Fisher exact test
-  MOTYPE mtype; // type of model 
-  PTYPE ptype; // type of prior 
-  PRIORS *priors; // the prior probabilities model 
-  P_POINT *p_point; // previously learned starting points 
-  ALPH_T *alph=NULL; // alphabet for dataset
+  OBJTYPE objfun = Classic;				// type of objective function 
+  TESTTYPE test = No_testtype;				// use Fisher exact test
+  MOTYPE mtype;						// type of model 
+  PTYPE ptype;						// type of prior 
+  PRIORS *priors;					// the prior probabilities model 
+  P_POINT *p_point;					// previously learned starting points 
+  ALPH_T *alph=NULL;					// alphabet for dataset
   MODEL *model=NULL, *best_model=NULL, *neg_model=NULL;
   DATASET *dataset=NULL, *neg_dataset=NULL;
-  int neg_n_samples=0;	// number of samples in negative dataset
-  double evt = BIG; // no E-value cutoff 
-  bool no_print = false; // turn off printing if parallel and not main 
-  char *plib_name = NULL; // use default library 
+  int neg_n_samples=0;					// number of samples in negative dataset
+  double evt = BIG;					// no E-value cutoff 
+  bool no_print = false; 				// turn off printing if parallel and not main 
+  char *plib_name = NULL; 				// use default library 
   bool show_version = false;
-  char *np = NULL;
-  bool sampling = true;	// sampling is on by default
-  bool mpi = false;	// not using MPI
+  char *np = NULL;					// value of the -np parameter
+  bool sampling = true;					// sampling is on by default
+  bool mpi = false;					// not using MPI
+  char *pp = NULL;					// used to silently pass the number np of processors
+							// in conjunction with mpi.
 
   spcons = new_string_list();	// initialize the consensus sequence list
 
@@ -286,7 +288,8 @@ void init_meme(
        NO_STATUS = true);
      DATA_OPTN(1, p, <np>, \t\tuse parallel version with <np> processors, np = _OPTION_);
      DATA_OPTN(1, sf, <sf>, \t\tprint <sf> as name of sequence file, sf = _OPTION_);
-     FLAG_OPTN(2, mpi, \t\tdo not use (set by exec_parallel), mpi = true);
+     FLAG_OPTN(2, mpi, \t\tDO NOT USE (set by exec_parallel), mpi = true);
+     DATA_OPTN(2, pp, <pp>, \t\tDO NOT USE (set by exec_parallel), pp = _OPTION_);
      FLAG_OPTN(2, check_syntax, \t\tcheck input syntax and exit,
        check_syntax = true);
      FLAG_OPTN(1, V, \t\t\tverbose mode, VERBOSE = true);
@@ -1276,11 +1279,13 @@ void init_meme(
   memcpy(&(dataset->control_groups), &control_groups, sizeof(GROUP_T));
 
   // save command line 
+  bool is_mpi = false;
+  if (strcmp(argv[argc-1], "-mpi") == 0) is_mpi = true;
   dataset->command = NULL;
   argv[0] = "meme";
   /*for (i=pos=len=0; i<argc-2; i++) {*/ // don't save last arguments 
   // save all arguments; used to not save last 2; why??? 
-  for (i=pos=len=0; i<argc; i++) {
+  for (i=pos=len=0; i<(is_mpi ? argc-1 : argc); i++) {
     len += strlen(argv[i])+1; // +1 for space following 
     Resize(dataset->command, len+2, char); // +1 for null 
     strcpy((dataset->command)+pos, argv[i]);
