@@ -503,6 +503,13 @@ Sint read_fasta_to_multiseqs(
 
   // Compute the letter frequencies in the sequences and put same values in train/test.
   // Average complementary letter frequencies if required.
+  // Add a uniform prior if nletters = 0.
+  if (nletters == 0) {
+    nletters = alen;
+    for (i=0; i<alen; i++) {
+      freqs[i] = 1;
+    }
+  }
   for (i=0; i<alen; i++) {
     train_multiseq->freqs[i] = use_rc ? (freqs[i]+freqs[I2CI(i)]) / (2.0*nletters) : freqs[i] / nletters;
     if (test_multiseq) test_multiseq->freqs[i] = train_multiseq->freqs[i];
