@@ -902,7 +902,10 @@ static ARRAYLST_T* load_motifs(
         if (value > max) max = value;
       }
     }
-    if (min == max) goto skip_motif; // motif can't be scaled!
+    if (min == max) {		// motif can't be scaled!
+      fprintf(stderr, "MAST: Cannot scale motif %d because minimum and maximum log-odds scores are the same.\n", nmotifs);
+      goto skip_motif; 
+    }
     // shuffle the motif if requested (EXPERIMENTAL OPTION)
     if (opts->shuffle) shuffle_motif(motif, &(opts->prng));
     // store the motif
@@ -915,7 +918,7 @@ static ARRAYLST_T* load_motifs(
 
   if (nmotifs == 0) die("No motifs found in file \"%s\".\n", opts->mo_source);
   if (arraylst_size(motifs) == 0) {
-    die("The motif selection criteria are too strict (options -remcorr, -m, -c -mev) and all motifs were excluded.\n");
+    die("MAST: All motifs were excluded because the motif selection criteria are too strict (options -remcorr, -m, -c -mev) or motifs could not be scaled.\n");
   }
 
   // return results
