@@ -6,6 +6,11 @@
  * COPYRIGHT: 1996, WNG
  * DESCRIPTION: Given MEME output, write a motif-based HMM.
  ********************************************************************/
+
+#ifdef MAIN
+#define DEFINE_GLOBALS
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -149,7 +154,7 @@ static void process_command_line(
     int c = 0;
     char* option_name = NULL;
     char* option_value = NULL;
-    const char * message = NULL;
+    const char* message = NULL;
 
 
     // Read the next option, and break if we're done.
@@ -158,7 +163,7 @@ static void process_command_line(
       break;
     } else if (c < 0) {
     	simple_getopterror(&message);
-      die("Error processing command line options (%s)\n", message);
+      die("Error processing command line options: %s\n", message);
     }
 
     if (strcmp(option_name, "type") == 0) {
@@ -202,7 +207,7 @@ static void process_command_line(
     } else if (strcmp(option_name, "spacerpseudo") == 0) {
       options->spacer_pseudo = atof(option_value);
     } else if (strcmp(option_name, "verbosity") == 0) {
-      verbosity = (VERBOSE_T)atoi(option_value);
+      verbosity = atoi(option_value);
     } else if (strcmp(option_name, "noheader") == 0) {
       options->print_header = false;
     } else if (strcmp(option_name, "noparams") == 0) {
@@ -846,9 +851,6 @@ bool store_requested_id(RBTREE_T *request_ids, char *value) {
 #ifdef MAIN
 #include "simple-getopt.h"
 
-VERBOSE_T verbosity = NORMAL_VERBOSE;
-
-
 /*************************************************************************
  * int main
  *************************************************************************/
