@@ -438,7 +438,7 @@ void parse_tsv_header(MOMO_OPTIONS_T* options,
                       size_t* len) {
   int i = 0;
   if (getline_nonempty(header, len, fp) != -1) {
-    *header = strsep(header, "\n");	// strip new line
+    *header = strsep(header, "\n\r");	// strip new line
     char *token;
     while((token = strsep(header, "\t")) != NULL) {
       // Trim leading & trailing whitespace from token.
@@ -527,7 +527,7 @@ void get_prealigned_mod_array(ARRAYLST_T* mod_array, char** modless,  char* sequ
  * an array with each position indicating whether or not it has a mod.
  * If yes, then will contain the mod name. Otherwise, it is set to NULL.
  */
-void get_tsv_mod_array(ARRAYLST_T* mod_array, char** modless, char* sequence, const char *alph_letters) {
+void get_tsv_mod_array(ARRAYLST_T* mod_array, char** modless, char* sequence, const char *alph_letters, char* unprocessed_sequence) {
   size_t seq_len = strlen(sequence);
   *modless = mm_malloc(seq_len + 1);
   *modless[0] = '\0';
@@ -536,19 +536,49 @@ void get_tsv_mod_array(ARRAYLST_T* mod_array, char** modless, char* sequence, co
   char* sequence_mod_iterator = sequence_mod_copy;
   char* ptr1 = strchr(sequence_mod_iterator, '[');
   char* ptr2 = strchr(sequence_mod_iterator, ']');  
+
+  // Check that the mod weight is not empty due to invalid format.
+  if (ptr2 == ptr1+1) {
+    fprintf(stderr, "The sequence is in an invalid PSM format: '%s'.\n", unprocessed_sequence);
+    exit(EXIT_FAILURE);
+  }
   
   // while mod has been found
   while (ptr1 && ptr2) {
     // find the length of the mod. For example, S[79.0] = 5 since we disregard the brackets.
-    int mod_len = ptr2-ptr1;
-
     // make sure mod is valid letter
     if (ptr1 > sequence_mod_iterator && strchr(alph_letters, *(ptr1-1))) {
+      int mod_len = ptr2-ptr1;
       // create a copy of the mod
       char* mod = mm_malloc(mod_len + 1);
       strncpy(mod, ptr1-1, 1);
       strncpy(mod+1, ptr1+1, mod_len - 1);
       mod[mod_len] = '\0';
+
+      // make sure the mod contains a valid weight or label
+      double dummy;
+      int nval = sscanf(mod+1, "%lf", &dummy);
+      if (nval != 1) {
+        // see if mod is a valid label
+        int mod_len = strlen(mod);
+        char *new_mod = mm_malloc(mod_len + 1);
+        new_mod[0] = mod[0];
+        new_mod[1] = '\0';
+        if (strcmp(mod+1, "Phospho (STY)") == 0) {
+          strncat(new_mod, "Phospho-STY", mod_len);
+        } else if (strcmp(mod+1, "Carbamidomethyl (C)") == 0) {
+          strncat(new_mod, "Carbamidomethyl-C", mod_len);
+        } else if (strcmp(mod+1, "Oxidation (M)") == 0) {
+          strncat(new_mod, "Oxidation-M", mod_len);
+        } else {
+	  fprintf(stderr, "Illegal mod weight or label value '%s' in PSM '%s'.\n", mod+1, unprocessed_sequence);
+	  exit(EXIT_FAILURE);
+        }
+        if (new_mod[1] != '\0') {
+          free(mod);
+          mod = new_mod;
+        }
+      }
       
       // update the modless sequence
       strncat(*modless, sequence_mod_iterator, ptr1-sequence_mod_iterator);
@@ -619,9 +649,12 @@ void add_phospho_file_to_table(char* phospho_filename,
   
   // for each body line (PSM) inside the file:
   bool found_mod = false;
+  int ptm_line_num = 0;
   while ((read = getline_nonempty(&line, &len, fp)) != -1) {
+    ptm_line_num++;
+
     // strip new line and make a copy
-    line = strsep(&line, "\n");
+    line = strsep(&line, "\n\r");
     
     char* unprocessed_sequence = NULL;
     char* sequence = NULL;
@@ -637,12 +670,34 @@ void add_phospho_file_to_table(char* phospho_filename,
       if (line == NULL || line[0] == '>') continue; 	// Skip FASTA ID lines.
       parse_prealigned_bodyline(&unprocessed_sequence, line, options->width);
     }
+
+    if (unprocessed_sequence == NULL) {
+      fprintf(stderr, "Skipping PTM line %d because it does not have at least %d fields.\n", 
+        ptm_line_num, index_of_sequence+1);
+      continue;
+    }
     
     if (options->filetype != Psm) {
       sequence = strdup(unprocessed_sequence);
     } else {
       // PSMs may appear in different formats, we will modify them to be in standard crux
-      if (strlen(unprocessed_sequence) > 2 && unprocessed_sequence[1] == '.') {
+      int useq_len = strlen(unprocessed_sequence);
+      if (useq_len > 1 && unprocessed_sequence[0] == '_') {
+        // sequences are in _[Acetyl (Protein N-term)]AES[Phospho (STY)]PAFLSAK_ format (format name??)
+        int seq_start = 0;
+        // Remove starting underscore.
+        seq_start = 1;
+        // Remove N-terminal mod if present.
+        if (strlen(unprocessed_sequence) > 2 && unprocessed_sequence[seq_start] == '[') {
+          seq_start = strchr(unprocessed_sequence, ']') - unprocessed_sequence + 1;
+        }
+        int seq_len = useq_len - seq_start;
+        // Remove ending underscore.
+        if (unprocessed_sequence[useq_len-1] == '_') seq_len--;
+        sequence = mm_malloc(seq_len + 1);
+        strncpy(sequence, unprocessed_sequence + seq_start, seq_len);
+        sequence[seq_len] = '\0';
+      } else if (strlen(unprocessed_sequence) > 2 && unprocessed_sequence[1] == '.') {
         // sequences are in A.AS[79.9]A.- format, remove the dots and '-' from ends.
         sequence = mm_malloc(strlen(unprocessed_sequence) + 1);
         sequence[0] = '\0';
@@ -710,7 +765,7 @@ void add_phospho_file_to_table(char* phospho_filename,
     int i_start, i_end;
     if (options->filetype == Psm) {
       // sequence contains multiple mods
-      get_tsv_mod_array(mod_array, &modless, sequence, alph_letters);
+      get_tsv_mod_array(mod_array, &modless, sequence, alph_letters, unprocessed_sequence);
       i_start = 0;
       i_end = seq_len;
     } else { // filetype = Raw or Fasta
@@ -783,7 +838,7 @@ void add_phospho_file_to_table(char* phospho_filename,
     fprintf(stderr, 
       "\nFATAL: No modified peptides were found in the PSM format (tab-delimited) file\n"
       "  \'%s\'.\n"
-      "Check that the peptides are in an allowable format (with modification weights)\n"
+      "Check that the peptides are in an allowable PSM format\n"
       "or enter them in 'raw' or 'FASTA' format.\n"
       "Refer to %s/doc/psm-format.html for allowable formats.\n",
 	phospho_filename, SITE_URL);
