@@ -6,6 +6,10 @@
  * COPYRIGHT: 2007, UQ
  ********************************************************************/
 
+#ifdef MAIN
+#define DEFINE_GLOBALS
+#endif
+
 #include <assert.h>
 #include <stdio.h>
 #include <string.h>
@@ -23,7 +27,6 @@
 #include "object-list.h"
 
 char* program_name = NULL;
-VERBOSE_T verbosity = NORMAL_VERBOSE;
 
 static void print_col_frequencies(ALPH_T *alph, ARRAY_T* alignment_col_freqs);
 
@@ -108,7 +111,7 @@ int main(int argc, char *argv[]) {
     int c = 0;
     char* option_name = NULL;
     char* option_value = NULL;
-    const char * message = NULL;
+    const char* message = NULL;
 
     // Read the next option, and break if we're done.
     c = simple_getopt(&option_name, &option_value, &option_index);
@@ -116,7 +119,7 @@ int main(int argc, char *argv[]) {
       break;
     } else if (c < 0) {
       (void) simple_getopterror(&message);
-      die("Error processing command line options (%s)\n", message);
+      die("Error processing command line options: %s\n", message);
     }
     
     if (strcmp(option_name, "model") == 0) {
