@@ -472,8 +472,8 @@ void convert_scores_to_pvalues
     ATYPE observed_score = get_array_item(i_observed, observed_scores);
 
     // Find the first null score that is worse than the observed score.
-    while ((((good_score_is_low == true) && (observed_score > null_score)) ||
-	    ((good_score_is_low == false) && (observed_score < null_score))) &&
+    while ((((good_score_is_low == true) && (observed_score >= null_score)) ||
+	    ((good_score_is_low == false) && (observed_score <= null_score))) &&
 	   (i_null < num_null)) {
       i_null++;
       if (i_null < num_null) {
@@ -484,7 +484,7 @@ void convert_scores_to_pvalues
     ATYPE pvalue = (ATYPE)(i_null + 1) / (ATYPE)(num_null + 1);
     set_array_item(i_observed, pvalue, observed_scores);
   }
-}
+} // convert_scores_to_pvalues
 
 /*****************************************************************************
  * MAIN
