@@ -555,7 +555,11 @@ void set_database_freq_and_entropy(
   }
   /* convert counts to frequencies */
   for (i=0; i < alph_size_core(alph); i++) {
-    dataset->res_freq[i] /= dataset->wgt_total_res;
+    if (dataset->wgt_total_res != 0) {
+      dataset->res_freq[i] /= dataset->wgt_total_res;
+    } else {
+      dataset->res_freq[i] = 1.0/alph_size_core(alph);
+    }
   }
 //fprintf(stderr, "wgt_total_res %f\n", dataset->wgt_total_res); exit(1);
 } // set_database_freq_and_entropy
