@@ -66,11 +66,6 @@ bool read_sequence(
       if ((i % RCHUNK) == 0) {
         Resize(name, i+RCHUNK, char);
       }
-      // change any non-ASCII codes to '_'
-      if (c > 127) {
-        fprintf(stderr, "FASTA sequence ID contains the non-ASCII character code %d; converted to '_'\n", c);
-        c = '_';
-      }
       name[i++] = c;                        /* non-blank: add to name */
     }
   }
@@ -221,10 +216,10 @@ static int read_sequence_de(
       /* alocate space for descriptor string */
       if ((length % RCHUNK) == 0) Resize(de, length+RCHUNK, char);
       // change any non-ASCII codes to '_'
-      if (c > 127) {
-        fprintf(stderr, "FASTA sequence descriptor contains the non-ASCII character code %d; converted to '_'\n", c);
-        c = '_';
-      }
+      //if (c > 127) {
+      //  fprintf(stderr, "FASTA sequence descriptor contains the non-ASCII character code %d; converted to '_'\n", c);
+      //  c = '_';
+      //}
       de[length++] = c;                        /* append character to de */
     }
     real_length++;
