@@ -7,6 +7,11 @@
  * DESCRIPTION: Remove from an alignment all columns that contain a gap
  *              in the specified species.
  *************************************************************************/
+
+#ifdef MAIN
+#define DEFINE_GLOBALS
+#endif
+
 #include "alignment.h"
 #include "clustalw-io.h"
 #include <stdio.h>
@@ -16,8 +21,6 @@
  *****************************************************************************/
 #ifdef MAIN
 
-VERBOSE_T verbosity = NORMAL_VERBOSE;
-
 int main
   (int    argc,
    char * argv[])
@@ -34,7 +37,7 @@ int main
   // Read the alignment.
   ALIGNMENT_T* big_alignment = read_alignment_from_file(
     alignment_filename,
-	  false, // sort by species name
+    false, // sort by species name
     false, // remove gaps
     NULL   // pointer to ref_seq_index not used
   );
