@@ -13,6 +13,7 @@ static char *DEFAULT_OUTPUT_DIRNAME = "sea_out";
 static const char *HTML_FILENAME = "sea.html";
 static const char *TSV_FILENAME = "sea.tsv";
 static const char *SEQUENCES_TSV_FILENAME = "sequences.tsv";
+static const char *SITES_TSV_FILENAME = "sites.tsv";
 static const char *TEMPLATE_FILENAME = "sea_template.html";
 
 /*****************************************************************************
@@ -27,22 +28,14 @@ static void usage(char *format, ...) {
     "   Options:\n"
     "     --p <filename>            primary (positive) sequence file name (required)\n"
     "     --m <filename>            motif file name (required, may be repeated)\n"
-/*    "     --objfun de|cd            objective function (<objfun>)\n"
-    "                                 de : Differential Enrichment\n"
-    "                                 cd : Central Distance\n"
-    "                               default: de\n"
-*/
     "     --n <filename>            control (negative) sequence file name;\n"
     "                               defaults: if --n is not given, then SEA\n"
     "                               creates one by shuffling the primary sequences\n"
+    "     --no-pgc                  do not show actual genomic coordinates for the motif\n"
+    "                               sites reported in the Sites TSV file\n"
     "     --notrim                  do not trim the control sequences even if their\n"
     "                               average length is greater the than primary sequences;\n"
     "                               default: trim control sequences if needed\n"
-/*
-    "                               creates control sequences as follows:\n"
-    "                                 <objfun> = de, shuffle primary sequences\n"
-    "                                          = cd, no control sequences allowed\n"
-*/
     "     --order <m>               estimate an m-order background model\n"
     "                               and use an m-order shuffle if creating\n"
     "                               control sequences from primary sequences;\n"
@@ -99,7 +92,7 @@ static void usage(char *format, ...) {
 // Be careful that there are not more than 62 options as otherwise the value
 // of '?' will be used.
 enum Opts {
-  OPT_M, OPT_P, OPT_N, OPT_NOTRIM, OPT_ORDER, OPT_O, OPT_OC, OPT_TEXT, //OPT_OBJFUN,
+  OPT_M, OPT_P, OPT_N, OPT_NOPGC, OPT_NOTRIM, OPT_ORDER, OPT_O, OPT_OC, OPT_TEXT, //OPT_OBJFUN,
   OPT_XALPH, OPT_BFILE, OPT_PSEUDOCOUNT, OPT_INC, OPT_EXC,
   OPT_HOFRACT, OPT_SEED, OPT_THRESH, OPT_QVALUE, OPT_PVALUE, OPT_DISTR, OPT_ALIGN,
   OPT_NOSEQS, OPT_DESC, OPT_DFILE, OPT_VERBOSITY, OPT_VERSION
@@ -113,13 +106,13 @@ static char *process_command_line(int argc, char* argv[], STREME_OPTIONS_T *opti
   struct option streme_options[] = {
     {"m", required_argument, NULL, OPT_M},
     {"p", required_argument, NULL, OPT_P},
+    {"no-pgc", no_argument, NULL, OPT_NOPGC},
     {"n", required_argument, NULL, OPT_N},
     {"notrim", no_argument, NULL, OPT_NOTRIM},
     {"order", required_argument, NULL, OPT_ORDER},
     {"o", required_argument, NULL, OPT_O},
     {"oc", required_argument, NULL, OPT_OC},
     {"text", no_argument, NULL, OPT_TEXT},
-    //{"objfun", required_argument, NULL, OPT_OBJFUN},
     {"xalph", required_argument, NULL, OPT_XALPH},
     {"hofract", required_argument, NULL, OPT_HOFRACT},
     {"seed", required_argument, NULL, OPT_SEED},
@@ -147,8 +140,8 @@ static char *process_command_line(int argc, char* argv[], STREME_OPTIONS_T *opti
   options->text_only = false;
   options->posfile = NULL;
   options->negfile = NULL;
+  options->parse_genomic_coord = true;
   options->notrim = false;
-  //options->objfun = DEFAULT_OBJFUN;
   options->order = -1;			// flags no option given
   options->alphabet_type = DEFAULT_ALPHABET_TYPE;
   options->alph = NULL;
@@ -193,6 +186,9 @@ static char *process_command_line(int argc, char* argv[], STREME_OPTIONS_T *opti
       case OPT_P:
         options->posfile = optarg;
         break;
+      case OPT_NOPGC:
+        options->parse_genomic_coord = False;
+        break;
       case OPT_N:
         options->negfile = optarg;
         break;
@@ -525,6 +521,9 @@ Model *motif2streme(
   model->alen = alph_size_core(model->alph);
   model->width = get_motif_length(motif);
   model->npassing = 0;
+  model->npos_passing = 0;
+  model->matches = NULL;
+  model->nmatches = 0;
   // PSPM
   for (i=0; i<model->alen; i++)
     for (j=0; j<model->width; j++)
@@ -685,6 +684,136 @@ static void print_passing_sequences_tsv(
 
 } // print_passing_sequences_tsv
 
+//
+// Print positive sites for each significant motif in TSV format.
+//
+void print_sea_positive_sites_tsv(
+  STREME_OPTIONS_T *options,    // STREME options
+  Model **models,               // the discovered motifs
+  int num_motifs 		// the number of motifs to output
+) {
+  int imotif, isite;
+  FILE *outfile = options->sites_tsv_output;
+
+  // Replace original strand???
+
+  // Reread the ALL primary sequences because sites got erased.
+  BOOL do_rc = alph_has_complement(options->alph);
+  ARRAY_T *back = NULL;                         // space for the MEME-style background
+  Multiseq *test_multiseq = NULL;
+  Multiseq *multiseq = read_pos_neg_seqs(options, do_rc, True, False, options->notrim, True, True, back, &test_multiseq);
+  free_array(back);
+
+  // Process each motif.
+  double log_thresh = log(options->thresh);
+  for (imotif=0; imotif<num_motifs; imotif++) {
+    Model *model = models[imotif]; MOTIF_T *motif = model->motif;
+    double score_threshold = model->score_threshold;
+    int width = model->width;
+
+    // Done if signficance threshold exceeded.
+    double log_significance = options->thresh_type == PVALUE ? model->test_log_pvalue : 
+      (options->thresh_type == QVALUE ? model->test_log_qvalue : model->test_log_evalue);
+    if (log_significance > log_thresh) break;
+
+    // Score ALL positive sequences saving ALL passing matches in each sequence.
+    score_model_pssm(options, multiseq, model, False, False, PASSING, False, False, True);
+    if (test_multiseq) score_model_pssm(options, test_multiseq, model, False, False, APPEND_PASSING, True, False, True);
+    Site *sites = model->matches;
+    int nsites = model->nmatches;
+
+    // Print the TSV header for first motif.
+    if (imotif == 0) {
+      fprintf(outfile,
+        "%s\t"                  // motif ID
+        "%s\t"                  // motif Alternate ID
+        "%s\t"                  // sequence ID
+        "%s\t"                  // site start
+        "%s\t"                  // site end
+        "%s\t"                  // strand
+        "%s\t"                  // site score
+        "%s\n",                 // site sequence
+        "motif_ID", "motif_ALT_ID", "seq_ID", "site_Start", "site_End", "site_Strand", "site_Score", "site_Sequence"
+      );
+    } else {
+      fprintf(outfile, "#\n");
+    }
+
+    // If parsing genomic coordinates, compute the starting position of site 
+    // in the chromosome so that ties will sort correctly.
+    if (options->parse_genomic_coord) {
+      for (isite=0; isite<nsites; isite++) {
+	Site *site = sites + isite;
+	if (! site->is_positive) continue;        // skip negative sequences
+	int seqno = site->seqno;
+	Multiseq *mseq = (site->is_holdout ? test_multiseq : multiseq);
+	char *seq_id = (char *) DESCRIPTIONPTR(mseq, seqno);
+	char *chr_name = NULL;
+	size_t chr_name_len;
+        int seq_start, seq_end;
+        if (parse_genomic_coordinates_helper(seq_id, &chr_name, &chr_name_len, &seq_start, &seq_end)) {
+	  site->pos += seq_start;
+	}
+      }
+    }
+
+    // Sort the positive sites by decreasing score.
+    qsort(sites, nsites, sizeof(Site), compare_site_score);
+
+    // Print the sorted positive sequence sites.
+    for (isite=0; isite<nsites; isite++) {
+      Site *site = sites + isite;
+      if (! site->is_positive) continue;        // skip negative sequences
+      int seqno = site->seqno;
+      Multiseq *mseq = (site->is_holdout ? test_multiseq : multiseq);
+      char *seq_id = (char *) DESCRIPTIONPTR(mseq, seqno);
+      char *chr_name = NULL;
+      size_t chr_name_len;
+      int seq_start, seq_end;
+      if (options->parse_genomic_coord &&
+        parse_genomic_coordinates_helper(seq_id, &chr_name, &chr_name_len, &seq_start, &seq_end)
+      ) {
+        seq_id = chr_name;
+        site->pos -= seq_start;
+        seq_start++;
+      } else {
+        seq_start = 1;
+      }
+      // Get the start of the site in the positive or rc sequence as needed.
+      Uchar *word;
+      if (do_rc && site->strand == '-') {
+        Uint seqlen = mseq->seqlengths[seqno];
+        Uint rc_seqstart = mseq->seqstarts[seqno] + mseq->totallength/2 + 1;
+        word = mseq->sequence + rc_seqstart + (seqlen - site->pos) - width;
+      } else {
+        word = mseq->sequence + mseq->seqstarts[seqno] + site->pos;
+      }
+      fprintf(outfile,
+        "%s\t"			// Motif ID
+        "%s\t"			// Motif Alternate ID
+        "%s\t"                  // Sequence ID
+        "%d\t"                  // site start position
+        "%d\t"                  // site end position
+        "%c\t"                  // site strand
+        "%.2f\t"                // site score
+        "%*.*s\n",              // site sequence
+        get_motif_id(motif), 				// Motif_ID
+        get_motif_id2(motif),				// Motif Alternate ID
+        seq_id,                                         // Sequence ID
+        seq_start + site->pos,                          // site start
+        seq_start + site->pos + width - 1,              // site end
+        (do_rc ? site->strand : '.'),                   // site strand
+        site->score,                                    // site score
+        width, width, word                              // site sequence
+      );
+      if (chr_name) free(chr_name);
+    } // passing sequence
+
+    // Free the sites.
+    free(sites);
+  } // motif
+} // print_sea_positive_sites_tsv
+
 //
 // Output the HTML, TSV and SEQUENCES_TSV results.
 //
@@ -910,7 +1039,7 @@ static void output_results(
       // Add the passing sequences from the hold-out sequence set.
       if (train_multiseq) {
 	// Free the matches in the model.
-	free(model->matches);
+	free(model->matches); model->matches = NULL; model->nmatches = 0;
 	// Score the second set of sequences getting just the ZOOPS sites (ignores score threshold).
 	score_model_pssm(options, train_multiseq, model, false, false, ZOOPS, false, false, false);
 	get_passing_sequences(options, model, train_multiseq, true, true);
@@ -919,21 +1048,24 @@ static void output_results(
     }
     
     // Free the matches in the model.
-    free(model->matches);
-    model->matches = NULL;
-    model->nmatches = 0;
+    free(model->matches); model->matches = NULL; model->nmatches = 0;
   } // motif
 
   // Finish the JSON output.
   if (json_output) jsonwr_end_array_value(json_output);
   if (json_output) jsonwr_end_object_value(json_output);
 
-  // Finish the TSV output.
+  // Finish the SEA TSV output.
   char *version_message = "# SEA (Simple Enrichment Analysis): Version " VERSION " compiled on " __DATE__ " at " __TIME__ "\n";
   fprintf(options->text_output, "\n%s", version_message);
   fprintf(options->text_output, "# The format of this file is described at %s/%s.\n", SITE_URL, "doc/sea-output-format.html");
   fprintf(options->text_output, "# %s\n", options->commandline);
 
+  // Write the SITES TSV output.
+  if (! options->text_only && options->noseqs == false) {
+    print_sea_positive_sites_tsv(options, models, num_motifs);
+  }
+
   // Finish the HTML output.
   if (html_output) {
     if (htmlwr_output(html_output) != NULL) {
@@ -975,17 +1107,25 @@ int main(int argc, char *argv[])
     if (create_output_directory(options.output_dirname, options.allow_clobber, false)) {
       exit(EXIT_FAILURE);
     }
-    // Create the path of the TSV output file and open it.
+    // Create the path of the SEA_TSV output file and open it.
     char *path = make_path_to_file(options.output_dirname, TSV_FILENAME);
     if ((options.text_output = fopen(path, "w")) == NULL) {
       fprintf(stderr, "ERROR: Unable to open TSV output file '%s' for writing.\n", path);
       exit(EXIT_FAILURE);
     }
-    // Create the path of the SEQUENCES_TSV output file and open it.
-    path = make_path_to_file(options.output_dirname, SEQUENCES_TSV_FILENAME);
-    if ((options.sequences_tsv_output = fopen(path, "w")) == NULL) {
-      fprintf(stderr, "ERROR: Unable to open SEQUENCES TSV output file '%s' for writing.\n", path);
-      exit(EXIT_FAILURE);
+    if (options.noseqs == false) {
+      // Create the path of the SEQUENCES_TSV output file and open it.
+      path = make_path_to_file(options.output_dirname, SEQUENCES_TSV_FILENAME);
+      if ((options.sequences_tsv_output = fopen(path, "w")) == NULL) {
+	fprintf(stderr, "ERROR: Unable to open SEQUENCES TSV output file '%s' for writing.\n", path);
+	exit(EXIT_FAILURE);
+      }
+      // Create the path of the SITES_TSV output file and open it.
+      path = make_path_to_file(options.output_dirname, SITES_TSV_FILENAME);
+      if ((options.sites_tsv_output = fopen(path, "w")) == NULL) {
+	fprintf(stderr, "ERROR: Unable to open SITES TSV output file '%s' for writing.\n", path);
+	exit(EXIT_FAILURE);
+      }
     }
   }
 
@@ -1023,7 +1163,7 @@ int main(int argc, char *argv[])
   // Note that we are swapping the training and hold-out sets here relative to STREME.
   options.nmotifs = 1;	// suppress warning message
   Multiseq *train_multiseq = NULL;
-  Multiseq *test_multiseq = read_pos_neg_seqs(&options, do_rc, True, false, options.notrim, true, back, &train_multiseq);
+  Multiseq *test_multiseq = read_pos_neg_seqs(&options, do_rc, true, false, options.notrim, true, false, back, &train_multiseq);
   if (train_multiseq) set_logcumback(&options, train_multiseq);
   set_logcumback(&options, test_multiseq);
 
