@@ -13,6 +13,11 @@
 #include "dmalloc.h"
 #endif
 
+#ifdef PARALLEL
+#include <mpi.h>
+  DEXTERN(MPI_Datatype *, SEED_PACKET_TYPE_PTR, NULL);
+#endif
+
 /**
  * An sp_matrix type. Stores the matrix, as an array of S_POINT pointers, as
  * well as information about the dimensions of the matrix and which rows
