@@ -26,6 +26,7 @@
 #include "io.h"
 #include "bed.h"
 #include "bed-io.h"
+#include "derangement.h"
 #include "gtf-io.h"
 #include "hash_table.h"
 #include "macros.h"
@@ -49,8 +50,8 @@
 #define HISTONE_FILE_NAME_FMT "^.*%s.*(broad|narrow)Peak$"
 #define EXPRESSION_FILE_NAME_FMT "^.*%s.*[.]gtf$"
 #define MAX_CHRM_LENGTH 1e9
-// Number or random permutations for estimating null distribution
-#define N_PERMS 10
+// Number or random derangements for estimating null distribution
+#define N_PERMS 44		// number of derangements of N=5 tissues 
 // Mean of Gaussian noise is minimum/NOISE_FRACTION
 #define NOISE_FRACTION 10.0
 
@@ -1299,8 +1300,8 @@ static void finish_link_table(
     // Have a tissue panel.
     ARRAY_T *null_scores = NULL;
     for (i_hist=0; i_hist<n_histones; i_hist++) {
-      scores = resize_array(scores, n_links);
-      null_scores = resize_array(null_scores, n_links*n_perms);
+      scores = resize_init_array(scores, n_links, 0);
+      null_scores = resize_init_array(null_scores, n_links*n_perms, 0);
       int n_scores = 0;
       int n_null = 0;
       char *histone = get_nth_string(i_hist, options->histone_names);
@@ -2334,14 +2335,30 @@ static void get_correlations(
   DEBUG_FMT(NORMAL_VERBOSE,
     "Getting the correlations for %d links for histone %s.\n", n_links, get_nth_string(i_hist, options->histone_names));
 
-  // Set up for permuting expression values for null distribution.
-  DEBUG_FMT(NORMAL_VERBOSE, "  Creating %d permutations of %d link indices.\n", n_perms, n_links);
-  int **perms = (int **) mm_malloc(sizeof(int *) * n_perms);
-  srand_mt(options->seed);					// Make sure the permutations are not affected by other things.
-  for (i=0; i<n_perms; i++) {
-    perms[i] = (int *)mm_malloc(sizeof(int) * n_links);
-    for (j=0; j<n_links; j++) perms[i][j] = i;			// Set permutation to identity.
-    SHUFFLE(perms[i], n_links);					// Make a permutation of the indices.
+  // Set up for permuting expression values across tissues for null distribution.
+  int **perms;
+  if (n_perms > N_PERMS) {
+    DEBUG_FMT(NORMAL_VERBOSE, "  Creating %d random derangements of expression across %d tissues.\n", n_perms, n_tissues);
+    perms = (int **) mm_malloc(sizeof(int *) * n_perms);
+    srand_mt(options->seed);					// Make sure the derangements are not affected by other things.
+    for (i=0; i<n_perms; i++) {
+      perms[i] = (int *)mm_malloc(sizeof(int) * n_tissues);
+      for (j=0; j<n_tissues; j++) perms[i][j] = j;		// Set permutation to identity.
+      SHUFFLE(perms[i], n_tissues);				// Make a permutation of the indices.
+      // Convert permutation to derangement: no index in its original position.
+      for (j=0; j<n_tissues; j++) {
+	if (perms[i][j] == j) {
+	  int rand_num = rand_int(n_tissues - 1) + 1;
+	  int new_index = j + rand_num;
+	  if (new_index >= n_tissues) new_index = new_index - n_tissues;
+	  perms[i][j] = perms[i][new_index];
+	  perms[i][new_index] = j;
+	}
+      }
+    }
+  } else {
+    DEBUG_FMT(NORMAL_VERBOSE, "  Creating all %d derangements of expression across %d tissues.\n", n_perms, n_tissues);
+    perms = get_derangements(n_tissues, n_perms);  
   }
 
   // Compute correlation of each link.
@@ -2357,20 +2374,15 @@ static void get_correlations(
     }
     // Compute correlation of link.
     double rho = pearson_correlation(n_tissues, transcript->expr, locus->histone_level,
-      NULL, NULL, NULL, NULL, true, options->valid_tissues[i_hist]);
+      NULL, NULL, NULL, NULL, true, options->valid_tissues[i_hist], NULL);
       
     // Round results so order of tissues doesn't matter.
     RND(rho*scale_factor, 8, link->correlation);
 
     // Compute correlation with permuted order of expression tissues.  Repeat n_perms times.
     for (i=0; i<n_perms; i++) {
-      int perm_i = perms[i][link_i];
-      // Check that permutation changed the link.
-      if (perm_i == link_i) perm_i = (link_i < n_links) ? perms[i][link_i+1] : perms[i][0]; 
-      LINK_T *perm_link = links[perm_i];
-      double *perm_expr = perm_link->transcript->expr;
-      rho = pearson_correlation(n_tissues, perm_expr, locus->histone_level,
-        NULL, NULL, NULL, NULL, true, options->valid_tissues[i_hist]);
+      rho = pearson_correlation(n_tissues, transcript->expr, locus->histone_level,
+        NULL, NULL, NULL, NULL, true, options->valid_tissues[i_hist], perms[i]);
       RND(rho*scale_factor, 8, link->perm_correlation[i]);
     }
   } // link 
@@ -2421,7 +2433,7 @@ int main(int argc, char *argv[]) {
   LINK_TABLE_T link_table;
   link_table.n_links = 0;
   link_table.links = NULL;
-  link_table.n_perms = N_PERMS;
+  link_table.n_perms = options.n_tissues > 5 ? N_PERMS+1 : get_num_derangements(options.n_tissues);
   link_table.have_tss_info = transcript_table->have_tss_info;
 
   // Add links to link table for each histone; (needed because max distance can vary)
