@@ -308,7 +308,7 @@ void get_pv_lookup_new(MATRIX_T* scores, int query_len, int targets_len, int ran
       set_matrix_row(address_index, pv, pv_lookup_matrix);
       free_array(pv);
       // UK: copy the pmf into the pmf matrix
-      set_matrix_row(address_index, pdf_new, pmf_matrix);
+      if (pmf_matrix) set_matrix_row(address_index, pdf_new, pmf_matrix);
 
       // Store the location of this pv lookup table in the reference array
       set_matrix_cell(start, start + i, (double) address_index, reference_matrix);
@@ -2280,8 +2280,8 @@ int main(int argc, char *argv[]) {
     pv_lookup_matrix = allocate_matrix(num_pv_lookup_array, num_array_lookups);
     init_matrix(0, pv_lookup_matrix);
     // setup pmf matrix; Notice that the size of this array is cubic in the query length!
-    pmf_matrix = allocate_matrix(num_pv_lookup_array, num_array_lookups);   // UK
-    init_matrix(0, pmf_matrix);
+    pmf_matrix = opts.complete_scores ? allocate_matrix(num_pv_lookup_array, num_array_lookups) : NULL;   // UK
+    if (pmf_matrix) init_matrix(0, pmf_matrix);
     // calculate pvalues
     get_pv_lookup_new(all_columnwise_scores, query_len, targets_len, BINS,
         reference_matrix, pv_lookup_matrix, pmf_matrix);
