@@ -60,62 +60,62 @@ AlphabetParser.prototype._parse_error = function(message) {
 //
 // Parse a header
 //
-AlphabetParser.prototype.parse_header = function(name, like) {
+AlphabetParser.prototype.parse_header = function(name, like, line_no) {
   "use strict";
   if (this.error) throw new Error("An error occurred previously");
   if (like != null && !like.match("^(?:RNA|DNA|PROTEIN)$"))
-      throw new Error("The like parameter must be RNA, DNA or PROTEIN");
+      throw new Error("Error in line " + line_no + ". The like parameter must be RNA, DNA or PROTEIN.");
   if (!this.seenHeader) {
     this.seenHeader = true;
     this.name = name;
     this.like = like;
   } else {
-    this._parse_error("Header already defined!");
+    this._parse_error("Error in line " + line_no + ". Custom alphabet header already defined!");
   }
 };
 
 //
 // Parse a symbol.
 //
-AlphabetParser.prototype.parse_symbol = function(sym, features) {
+AlphabetParser.prototype.parse_symbol = function(sym, features, line_no) {
   "use strict";
   if (this.error) throw new Error("An error occurred previously");
   var i;
   if (features == null) features = {};
-  if (!this.SYMBOL_RE.test(sym)) this._parse_error("Symbol invalid");
+  if (!this.SYMBOL_RE.test(sym)) this._parse_error("Error in line number " + line_no + ": Symbol '" + sym + "' is invalid.");
   var name = null;
   if (features.name != null && features.name != "") {
     name = features.name;
   }
   var colour = 0;
   if (features.colour != null && features.colour != "") {
-    if (!this.COLOUR_RE.exec(features.colour)) this._parse_error("Colour invalid");
+    if (!this.COLOUR_RE.exec(features.colour)) this._parse_error("Error in line number " + line_no + ": Color '" + features.colour + "' is invalid.");
     colour = parseInt(features.colour, 16);
   }
   var complement = null;
   if (features.complement != null && features.complement != "") {
-    if (!this.SYMBOL_RE.test(features.complement)) this._parse_error("Complement invalid");
+    if (!this.SYMBOL_RE.test(features.complement)) this._parse_error("Error in line number " + line_no + ": Complement '" + features.complement + "' is invalid.");
     complement = features.complement;
   }
   var comprise = null;
   if (features.comprise != null && features.comprise != "") {
-    if (!this.SYMBOLS_RE.test(features.comprise)) this._parse_error("Comprise invalid");
+    if (!this.SYMBOLS_RE.test(features.comprise)) this._parse_error("Error in line number " + line_no + ": Comprise '" + features.comprise + "' is invalid.");
     // sort and remove duplicates
     comprise = features.comprise.split("").sort(AlphabetUtil.sym_compare);
     comprise = comprise.filter(function (item, pos, ary) { return pos == 0 || item != ary[pos - 1]; });
   }
   var aliases = [];
   if (features.aliases != null && features.aliases != "") {
-    if (!this.SYMBOLS_RE.test(features.aliases)) this._parse_error("Aliases invalid");
+    if (!this.SYMBOLS_RE.test(features.aliases)) this._parse_error("Error in line number " + line_no + ": Aliases " + features.aliases + " are invalid.");
     aliases = features.aliases.split("").sort(AlphabetUtil.sym_compare);
   }
   if (this.allSymbols[sym]) {
-    this._parse_error("Symbol already defined");
+    this._parse_error("Error in line number " + line_no + ": Symbol '" + sym + "' is already defined.");
     return;
   }
   for (i = 0; i < aliases.length; i++) {
     if (this.allSymbols[aliases[i]]) {
-      this._parse_error("Symbol already defined");
+      this._parse_error("Error in line number " + line_no + ": Alias '" + aliases[i] + "' is already defined.");
       return;
     }
   }
@@ -133,7 +133,7 @@ AlphabetParser.prototype.parse_symbol = function(sym, features) {
     this.seenAmbiguous = true;
     for (i = 0; i < comprise.length; i++) {
       if (!this.coreSymbols[comprise[i]]) {
-        this._parse_error("Unknown core symbol");
+        this._parse_error("Error in line number " + line_no + ": Symbol '" + comprise[i] + "' is not a core symbol.");
         return;
       }
     }
@@ -163,7 +163,7 @@ AlphabetParser.prototype.parse_symbol = function(sym, features) {
 //
 // Parse a line from an alphabet file.
 //
-AlphabetParser.prototype.parse_line = function(line) {
+AlphabetParser.prototype.parse_line = function(line, line_no) {
   "use strict";
   if (this.error) throw new Error("An error occurred previously");
   this.lineNo++;
@@ -171,16 +171,16 @@ AlphabetParser.prototype.parse_line = function(line) {
   if (line2 === "")  return;
   var m;
   if ((m = this.HEADER_RE.exec(line2)) != null) {
-    this.parse_header(AlphabetParser.parse_name(m[1]), m[2]);
+    this.parse_header(AlphabetParser.parse_name(m[1]), m[2], line_no);
   } else if ((m = this.CORE_PAIR_RE.exec(line2)) != null) {
-    this.parse_symbol(m[1], {name: AlphabetParser.parse_name(m[2]), colour: m[3], complement: m[4]});
-    this.parse_symbol(m[4], {name: AlphabetParser.parse_name(m[5]), colour: m[6], complement: m[1]});
+    this.parse_symbol(m[1], {name: AlphabetParser.parse_name(m[2]), colour: m[3], complement: m[4]}, line_no);
+    this.parse_symbol(m[4], {name: AlphabetParser.parse_name(m[5]), colour: m[6], complement: m[1]}, line_no);
   } else if ((m = this.CORE_SINGLE_RE.exec(line2)) != null) {
-    this.parse_symbol(m[1], {name: AlphabetParser.parse_name(m[2]), colour: m[3]});
+    this.parse_symbol(m[1], {name: AlphabetParser.parse_name(m[2]), colour: m[3]}, line_no);
   } else if ((m = this.AMBIG_RE.exec(line2)) != null) {
-    this.parse_symbol(m[1], {name: AlphabetParser.parse_name(m[2]), colour: m[3], comprise: m[4]});
+    this.parse_symbol(m[1], {name: AlphabetParser.parse_name(m[2]), colour: m[3], comprise: m[4]}, line_no);
   } else {
-    this._parse_error("Alphabet line does not match a known pattern!");
+    this._parse_error("Error in line " + line_no + ". Line does not match a known pattern.  Line is: '" + line + "'");
   }
 };
 
@@ -398,17 +398,21 @@ AlphabetParser.prototype.parse_done = function() {
   return obj;
 };
 
-AlphabetParser.prototype.process_blob = function (blob) {
+AlphabetParser.prototype.process_blob = function (blob, handler) {
   "use strict";
-  if (blob.size > 10000) {
-    if (typeof this.handler.error == "function") {
-      this.handler.error(true, "This file is too large to be an alphabet definition.");
-    }
-    return;
+  // file name length error
+  if (handler.max_file_name_length != null && blob.name != null && blob.name.length > handler.max_file_name_length) {
+    this.handler.error(true, "The alphabet file name is too long: " + blob.name.length + " > " + handler.max_file_name_length + ".");
+  }
+  // file size error
+  if (handler.max_file_size != null && blob.size > handler.max_file_size) {
+    this.handler.error(true, "This file is too large to be an alphabet definition. ", 
+    ["File is over " + (blob.size/1000000).toPrecision(2) + "MB but must be no greater than " + handler.max_file_size/(1000000) + "MB"])
   }
   // setup the reader
   var me = this; // so we can access 'this' inside the closure
   var reader = new FileReader();
+  var line_no = 0;
   reader.onload = function(evt) {
     "use strict";
     var chunk, format, message;
@@ -437,6 +441,7 @@ AlphabetParser.prototype.process_blob = function (blob) {
     while ((code = decoder.next()) != null) {
       letter = String.fromCharCode(code);
       if (letter == '\n') {
+        line_no++;
         // return the line - first remove any leading or trailing carrage return chars
         // as I'm assuming that they're part of the newline
         if (line.charAt(0) == '\r') {
@@ -446,7 +451,7 @@ AlphabetParser.prototype.process_blob = function (blob) {
           line = line.slice(0, -1);
         }
         try {
-          me.parse_line(line);
+          me.parse_line(line, line_no);
         } catch (e) {
           if (e instanceof AlphabetError) {
             if (typeof me.handler.error == "function") me.handler.error(true, e.message);
@@ -462,7 +467,8 @@ AlphabetParser.prototype.process_blob = function (blob) {
       line += letter;
     }
     try {
-      if (line.length > 0) me.parse_line(line);
+      line_no++;
+      if (line.length > 0) me.parse_line(line, line_no);
       var alphabet_data = me.parse_done();
       if (typeof me.handler.data == "function") me.handler.data(alphabet_data);
     } catch (e) {
