@@ -109,9 +109,10 @@ BgParser.prototype._signal_stop = function () {
 
 BgParser.prototype._error = function (offset, line, column, code, message, data) {
   if (window.console && console.log) {
-    console.log("BG PARSER ERROR - offset: " + offset + "  line: " + line +
-        "  column: " + column + "  code: " + code + "  message: " + message +
-        "\ndata: " + JSON.stringify(data));
+    // Uncomment for debugging.
+    //console.log("BG PARSER ERROR - offset: " + offset + "  line: " + line +
+    //    "  column: " + column + "  code: " + code + "  message: " + message +
+    //    "\ndata: " + JSON.stringify(data));
   }
   if (typeof this.handler.error == "function") {
     this.handler.error(offset, line, column, code, message, data);
@@ -120,7 +121,7 @@ BgParser.prototype._error = function (offset, line, column, code, message, data)
 
 BgParser.prototype._error_here = function (code, message, data) {
   this._error(this.decoder.offset(), this.decoder.line(), this.decoder.column(),
-      code, message, data);
+    code, message, data);
 };
 
 BgParser.prototype._process_start = function (code, type) {
@@ -383,7 +384,7 @@ BgParser.prototype.process_blob = function (blob, offset, chunk_size) {
   if (typeof chunk_size === "undefined") chunk_size = 1 << 12;
   // update the progress
   if (offset === 0 && typeof this.handler.begin == "function")
-    this.handler.begin(blob.size);
+    this.handler.begin(blob.name, blob.size);
   if (typeof this.handler.progress == "function")
     this.handler.progress(offset / blob.size, this.syms);
   // setup the reader
@@ -453,11 +454,17 @@ var BgHandler = function(options) {
 BgHandler.prototype.configure = function (options) {
   "use strict";
   if (typeof options != "object" || options == null) options = {};
-  // configure file size
-  if (typeof options.file_max == "number") {
-    this.max_file_size = options.file_max;
+  // specify a maximum file size
+  if (typeof options.max_file_size == "number") {
+    this.max_file_size = options.max_file_size;
   } else {
-    this.max_file_size = 1 << 20;
+    this.max_file_size = 1000000;
+  }
+  // specify a maximum file name length
+  if (typeof options.max_file_name_len == "number" && options.max_file_name_len >= 1) {
+    this.max_file_name_length = options.max_file_name_len;
+  } else {
+    this.max_file_name_length = null;
   }
   // configure expected alphabet
   if (options.alphabet != null && options.alphabet instanceof Alphabet) {
@@ -530,9 +537,13 @@ BgHandler.prototype.summary = function () {
     if (is_error) error = true;
     else warning = true;
   };
-  // file size warning
+  // file name length error
+  if (this.max_file_name_length != null && this.file_name != null && this.file_name.length > this.max_file_name_length) {
+    add(true, "The background file name is too long: " + this.file_name.length + " > " + this.max_file_name_length + ".");
+  }
+  // file size error 
   if (this.max_file_size != null && this.file_size > this.max_file_size) {
-    add(false, "Large file", ["File is " + (Math.round(this.file_size / (1<<20) )) + "MB"])
+    add(true, "Large file", ["File is over " + Math.trunc(this.file_size /(1000000)) + "MB but must be no greater than " + this.max_file_size/(1000000) + "MB"])
   }
   // encoding or format error
   help = " - re-save as plain text; either Unicode UTF-8 (no Byte Order Mark) or ASCII";
@@ -573,7 +584,7 @@ BgHandler.prototype.summary = function () {
     }
     reason += (this.mismatches.line_count == 1 ? "line " : "lines ") +
       this.mismatches.lines_str();
-    add(true, "Alphabet is inconsistant", [reason]);
+    add(true, "Alphabet is inconsistent", [reason]);
   }
   // report duplicated chains
   if (this.duplicates.faults() > 0) {
@@ -670,8 +681,9 @@ BgHandler.prototype.summary = function () {
     "syms": this.syms, "guess_alphabet": this.guess_alphabet};
 };
 
-BgHandler.prototype.begin = function (file_size) {
+BgHandler.prototype.begin = function (file_name, file_size) {
   this.reset();
+  this.file_name = file_name;
   this.file_size = file_size;
   this.updated = true;
 };
@@ -699,6 +711,7 @@ BgHandler.prototype.error = function (offset, line, column, code, message, data)
     case BgErrorType.ENCODING:
       this.encoding_error = data["enc_code"];
       break;
+    case BgErrorType.FILE_NAME_LENGTH:
     case BgErrorType.JUNK:
     case BgErrorType.BAD_PROBABILITY:
     case BgErrorType.MISSING_PROBABILITY:
