@@ -68,7 +68,10 @@ var MotifInput = function(container, options) {
   this.file_popup = this.file_surround.querySelector("div.popup");
   // get the embed related parts
   this.embed_surround = this.container.querySelector("span.motif_embed");
+  this.embed_indicator = (this.embed_surround != null ? this.embed_surround.querySelector("span.indicator") : null);
+  this.embed_popup = (this.embed_surround != null ? this.embed_surround.querySelector("div.popup") : null);
   this.embed_hin = (this.embed_surround != null ? this.embed_surround.querySelector("input.data") : null);
+  this.embed_descr = (this.embed_surround != null ? this.embed_surround.querySelector("input.name"): null);
   // get the area used to display the alphabet
   this.alph_info = this.container.querySelector("span.motif_alphabet_info");
   // get the database related parts
@@ -95,12 +98,13 @@ var MotifInput = function(container, options) {
       throw new Error("No alphabets were allowed!");
     }
   }
+
   // parse the embeded motifs
   if (this.embed_hin) {
     (new MotifParser({
       "error": function(is_error, message, reasons) {
         me._embed_error(is_error, message, reasons); },
-      "begin": function(size) { me._embed_begin(size); },
+      "begin": function(embed_descr) { me._embed_begin(me.embed_descr.value); },
       "end": function () { me._embed_end(); },
       "meta": function (info) { me._embed_motif_meta(info); },
       "motif": function (motif) { me._embed_motif(motif); }
@@ -111,6 +115,7 @@ var MotifInput = function(container, options) {
   this.popup = document.createElement("canvas");
   this.popup.className = "pop_logo";
   document.getElementsByTagName("body")[0].appendChild(this.popup);
+
   // activate motif editor
   this._source_update();
   this._file_update();
@@ -395,7 +400,7 @@ MotifInput.prototype.get_motif_count = function () {
     return this.file_motifs.length;
   } else if (source == "embed") {
     return this.embed_motifs.length;
-  } else { // db
+  } else { 				// DB 
     return this.db_motif_count;
   }
   return 0;
@@ -460,6 +465,9 @@ MotifInput.prototype._text_mouseout = function (e) {
  ******************************************************************************/
 MotifInput.prototype._file_update = function () {
   var file, me;
+  // Delete existing input motifs.
+  this.text_motifs = [];
+  this.file_motifs = [];
   // cancel previous parsing operation
   if (this.file_parser) {
     this.file_parser.cancel();
@@ -478,8 +486,8 @@ MotifInput.prototype._file_update = function () {
   this.file_parser = new MotifParser({
     "error": function(is_error, message, reasons) {
       me._file_error(is_error, message, reasons); },
-    "begin": function(size) { me._file_begin(size); },
-    "end": function (error_list) { me._file_end(error_list); },
+    "begin": function(file_size, file_name) { me._file_begin(file_size, file_name); },
+    "end": function () { me._file_end(); },
     "progress": function (fraction) { me._file_progress(fraction); },
     "meta": function (info) { me._file_motif_meta(info); },
     "motif": function (motif) { me._file_motif(motif); }
@@ -493,15 +501,29 @@ MotifInput.prototype._file_update = function () {
  * Updates the state used by check() to decide if the field is valid.
  ******************************************************************************/
 MotifInput.prototype._embed_error = function (is_error, message, reasons) {
+  this._add_error_entry(this.embed_popup, is_error, message, reasons);
   this.embed_error |= is_error;
+  if (this.embed_error) {
+    substitute_classes(this.embed_surround, ["good", "warning"], ["error"]);
+  } else {
+    substitute_classes(this.embed_surround, ["good"], ["warning"]);
+  }
 };
 
 /******************************************************************************
  * CALLBACK HANDLER
  * Called when parsing the embeded motif begins.
- * Currently does nothing.
  ******************************************************************************/
-MotifInput.prototype._embed_begin = function (size) {
+MotifInput.prototype._embed_begin = function (embed_descr) {
+  substitute_classes(this.embed_surround, ["warning", "error"], ["good"]);
+  this.embed_indicator.style.width = "100%";
+  this.embed_popup.innerHTML = "";
+  this.embed_error = false;
+  var source_name = embed_descr.split(" ")[4];	// "motif number N from file_name"
+  if (typeof this.options["max_file_name_len"] === "number" && source_name.length > this.options["max_file_name_len"]) {
+    this._embed_error(true, "The name of the submitting file is too long.  Submitting file name must be no longer than "
+      + (this.options["max_file_name_len"]) + " characters but is " + source_name.length + " characters. ");
+  }
 };
 
 /******************************************************************************
@@ -510,6 +532,8 @@ MotifInput.prototype._embed_begin = function (size) {
  * When the source is set to the embedded motifs it fires the motifs_loaded event.
  ******************************************************************************/
 MotifInput.prototype._embed_end = function () {
+  this.embed_indicator.style.width = "100%";
+  if (!(this.embed_error)) substitute_classes(this.embed_surround, ["good"], []);
   if (this.source.value == "embed") this._fire_motifs_loaded();
 };
 
@@ -520,7 +544,19 @@ MotifInput.prototype._embed_end = function () {
  ******************************************************************************/
 MotifInput.prototype._embed_motif_meta = function (info) {
   "use strict";
-  this.embed_meta = info;
+  var motif_id = info.motif_id;
+  if (motif_id != null) {
+    // Check the length of the motif_id.
+    var motif_index = info.motif_index;
+    if (motif_index == null) motif_index = this.get_motif_count()+1;
+    if (typeof this.options["max_name_len"] === "number" && motif_id.length > this.options["max_name_len"]) {
+      this._embed_error(true, "Error in submitted motifs: The ID of submitted motif number " + motif_index
+        + " is too long.  Motif ID must be no longer than " + this.options["max_name_len"] 
+        + " characters but is " + motif_id.length + " characters.");
+    }
+  } else {
+    this.embed_meta = info;
+  }
 };
 
 /******************************************************************************
@@ -586,17 +622,23 @@ MotifInput.prototype._file_error = function (is_error, message, reasons) {
  * Called when parsing the motif file begins.
  * Clears all the errors and warnings from previous file parses.
  * Clears the displayed alphabet name.
- * Checks the size of the file to ensure it isn't too large to be considered.
+ * Checks the size of the file to ensure it isn't too large to be considered
+ * and checks that the file name is not too long.
  ******************************************************************************/
-MotifInput.prototype._file_begin = function (size) {
+MotifInput.prototype._file_begin = function (file_size, file_name) {
   "use strict";
   substitute_classes(this.file_surround, ["warning", "error"], ["good"]);
   this.file_indicator.style.width = "0%";
   this.file_popup.innerHTML = "";
   this.file_error = false;
-  if (typeof this.options["max_size"] === "number" && size > this.options["max_size"]) {
-    this._file_error(true, "The file is larger than the maximum accepted size.",
-        ["" + size + " > " +  this.options["max_size"]]);
+  if (typeof this.options["max_file_size"] === "number" && file_size > this.options["max_file_size"]) {
+    this._file_error(true, "Motif file is too large.  File size must be no larger than "
+      + (this.options["max_file_size"]/1000000) + "MB but is over "
+      + (Math.trunc(file_size/1000000)) + "MB" + ". ");
+  }
+  if (typeof this.options["max_file_name_len"] === "number" && file_name.length > this.options["max_file_name_len"]) {
+    this._file_error(true, "Motif file name is too long.  File name must be no longer than "
+      + this.options["max_file_name_len"] + " characters but is " + file_name.length + " characters. ");
   }
   this._show_alph_name(null);
 };
@@ -630,20 +672,34 @@ MotifInput.prototype._file_progress = function (fraction) {
  * Called when the motif file's alphabet and background have been loaded.
  * Stores the loaded information.
  * Checks that the alphabet is valid for the alphabet type.
+ * If info contains motif_id, just checks it for valid length and skips
+ * all other steps.
  ******************************************************************************/
 MotifInput.prototype._file_motif_meta = function (info) {
-  this.file_meta = info;
-  this._show_alph_name();
-  if (info.alphabet != null && info.alphabet instanceof Alphabet) {
-    if (!this.alph_type.matches(info.alphabet)) {
-      this._file_error(true, "" + info.alphabet + " motifs are not accepted by this tool.");
+  var motif_id = info.motif_id;
+  if (motif_id != null) {
+    // Check the length of the motif_id.
+    var motif_index = info.motif_index;
+    if (motif_index == null) motif_index = this.get_motif_count()+1;
+    if (typeof this.options["max_name_len"] === "number" && motif_id.length > this.options["max_name_len"]) {
+      this._file_error(true, "The ID of motif number " + motif_index
+        + " is too long.  Motif ID must be no longer than " + this.options["max_name_len"] 
+        + " characters but is " + motif_id.length + " characters.");
     }
   } else {
-    throw new Error("Unknown alphabet");
-  }
-  // TODO this is for debugging, it can be removed later
-  if (window.console && console.log) {
-    //console.log("version: " + info.version + " alphabet: " + info.alphabet + " norc: " + info.norc + " background: " + JSON.stringify(info.background));
+    this.file_meta = info;
+    this._show_alph_name();
+    if (info.alphabet != null && info.alphabet instanceof Alphabet) {
+      if (!this.alph_type.matches(info.alphabet)) {
+	this._file_error(true, "" + info.alphabet + " motifs are not accepted by this tool.");
+      }
+    } else {
+      throw new Error("Unknown alphabet");
+    }
+    // TODO this is for debugging, it can be removed later
+    if (window.console && console.log) {
+      //console.log("version: " + info.version + " alphabet: " + info.alphabet + " norc: " + info.norc + " background: " + JSON.stringify(info.background));
+    }
   }
 };
 
@@ -774,7 +830,7 @@ MotifInput.prototype._cust_alphabet_update = function() {
       me._cust_data(alphabet_data);
     }
   });
-  parser.process_blob(file);
+  parser.process_blob(file, this);
 };
 
 /******************************************************************************
