@@ -202,34 +202,6 @@ BEDIH.prototype._update_display = function () {
 
 }
 
-BEDIH.prototype.configure = function (options) {
-  if (typeof options != "object" || options == null) options = {};
-  // configure maximum file size
-  if (typeof options.file_max == "number") {
-    this.max_file_size = options.file_max;
-  } else {
-    this.max_file_size = null; // 20 MB
-  }
-  // specify a maximum name length?
-  if (typeof options.max_name_len == "number" && options.max_name_len >= 1) {
-    this.max_name_length = options.max_name_len;
-  } else {
-    this.max_name_length = null;
-  }
-  // specify a maximum description length?
-  if (typeof options.max_desc_len == "number" && options.max_desc_len >= 1) {
-    this.max_desc_length = options.max_desc_len;
-  } else {
-    this.max_desc_length = null;
-  }
-  // specifiy the maximum number of loci
-  if (typeof options.max_loci == "number" && options.max_loci >= 1) {
-    this.max_loci = options.max_loci;
-  } else {
-    this.max_seq_count = null;
-  }
-}
-
 BEDIH.prototype.reset = function () {
   "use strict";
   BedHandler.prototype.reset.apply(this, arguments);
@@ -264,19 +236,22 @@ BEDIH.prototype.end = function () {
 /******************************************************************************
  * Construct the manager of the alphabet input.
  ******************************************************************************/
-var AlphabetInput = function(container) {
+var AlphabetInput = function(container, options) {
   "use strict";
   var me;
   // make 'this' accessable in inner scopes
   me = this;
   // get the parts
   this.container = container;
+  this.options = options;
   // get radio buttons
   this.radio_custom_on = this.container.querySelector("input[type='radio'][value='1']");
   this.radio_custom_off = this.container.querySelector("input[type='radio'][value='0']");
   this.last_radio = null;
+
   // get the custom alphabet related parts
   this.cust_surround = this.container.querySelector("span.custom_alphabet");
+  this.cust_indicator = this.cust_surround.querySelector("span.indicator");
   this.cust_input = this.cust_surround.querySelector("input");
   this.cust_popup = this.cust_surround.querySelector("div.popup");
   this.cust_error = false;
@@ -300,7 +275,32 @@ var AlphabetInput = function(container) {
       }, 50);
     }, false);
   }
-};
+  // specify a maximum file size
+  if (typeof options.max_file_size == "number") {
+    this.max_file_size = options.max_file_size;
+  } else {
+    this.max_file_size = 10000;
+  }
+  // specify a maximum file name length
+  if (typeof options.max_file_name_len == "number" && options.max_file_name_len >= 1) {
+    this.max_file_name_length = options.max_file_name_len;
+  } else {
+    this.max_file_name_length = null;
+  }
+}; // AlphabetInput
+
+
+/******************************************************************************
+ * Checks the alphabet
+ ******************************************************************************/
+AlphabetInput.prototype.check = function() {
+  "use strict";
+  if (this.cust_error) {
+    alert("Please correct errors in the sequence alphabet.");
+    return false;
+  }
+  return true;
+}
 
 /******************************************************************************
  * Resets the alphabet input to the default state.
@@ -451,6 +451,7 @@ AlphabetInput.prototype._alphabet_update = function() {
   // check for a file to load
   if (!(file = this.cust_input.files[0])) {
     // no file to load! Clear the status. 
+    this.cust_indicator.style.width = "0%";
     substitute_classes(this.cust_surround, ["good", "warning", "error"], []);
     this._fire_alphabet_event();
   } else {
@@ -466,7 +467,8 @@ AlphabetInput.prototype._alphabet_update = function() {
         me._parse_data(alphabet_data);
       }
     });
-    parser.process_blob(file);
+    parser.process_blob(file, this);
+    this.cust_indicator.style.width = "100%";
   }
 };
 
@@ -487,6 +489,7 @@ AlphabetInput.prototype._radio_update = function(radio_button) {
     this.cust_input.value = "";
   }
   toggle_class(this.container, "custom", this.radio_custom_on.checked);
+  this._alphabet_update();
 };
 
 /******************************************************************************
@@ -508,7 +511,7 @@ var SequenceInput = function(container, options) {
   // for making XMLHttpRequests
   this._xml_alph = this.alph_type.bitset();
   this._xml_short = (options.short_only ? 1 : 0);
-  // lookup relevent components
+  // lookup relevant components
   this.prior_filter = this.container.querySelector("input.prior_filter");
   this.source = this.container.querySelector("select.sequence_source");
   // get the text related parts
@@ -584,13 +587,13 @@ var SequenceInput = function(container, options) {
     (new FastaChecker(this.embed_handler, this.alph_type.get_standard_alphabets())).process_blob(
         new Blob([this.embed_data.value], {"type": "text\/plain"}));
   }
-  // initialise
+  // initialize
   this.priors_filter_update();
   this._source_update();
   this.text_update();
   this.file_update();
   this.bed_file_update();
-  this._bed_file_db_category_update();
+
   // add listeners
   if (this.prior_filter != null) {
     this.prior_filter.addEventListener('click', function() {
@@ -598,52 +601,98 @@ var SequenceInput = function(container, options) {
       me._source_update();
     }, false);
   }
+
+  // detect change in sequence source
   this.source.addEventListener('change', function() {
-    me._source_update();
+    me._source_update(true);
   }, false);
-  // detect typing or pasting into motif text area
+
+  // detect typing or pasting into sequence text area
   this.text_area.addEventListener('input', function() {
     me.text_update(); 
   }, false);
-  // detect file changes
+
+  // detect uploaded sequence file changes
   this.file_input.addEventListener('change', function() {
     me.file_update();
   }, false);
-  // detect BED file changes
-  if (typeof this.bed_file_input !== "undefined") {
-    this.bed_file_input.addEventListener('change', function() {
-      me.bed_file_update();
-    }, false);
-  }
+
+  //
+  // BED FILES
+  //
+
   // detect BED file db category changes
   if (typeof this.bed_file_input !== "undefined") {
     this.bed_file_db_category.addEventListener('change', function() {
-      me._bed_file_db_category_update();
+      // Save the new BED file category in a hidden field for BACK and REFRESH.
+      document.getElementById(me.bed_file_input.name + "_selected_db_category").value = me.bed_file_db_category.selectedIndex;
+      // Reset the BED file listing and version to 0 and save in hidden fields.
+      me.bed_file_db_listing.selectedIndex = document.getElementById(me.bed_file_input.name + "_selected_db_listing").value = 0;
+      me.bed_file_db_version.selectedIndex = document.getElementById(me.bed_file_input.name + "_selected_db_version").value = 0;
+      // Reload the dynamic menus starting with listings and validate the BED file.
+      me._load_bed_file_db_listings();
     }, false);
   }
-  // detect BED db changes
+
+  // detect BED file listing changes
   if (this.bed_file_db_listing != null) {
     this.bed_file_db_listing.addEventListener('change', function() {
-      me._load_bed_file_db_versions(me.bed_file_db_listing.value)
+      // Save the new BED file listing in a hidden field for BACK and REFRESH.
+      document.getElementById(me.bed_file_input.name + "_selected_db_listing").value = me.bed_file_db_listing.selectedIndex;
+      // Reset the BED file version to 0 and save in a hidden field.
+      me.bed_file_db_version.selectedIndex = document.getElementById(me.bed_file_input.name + "_selected_db_version").value = 0;
+      // Reload the dynamic menus starting with versions and validate the BED file.
+      me._load_bed_file_db_versions();
     }, false);
   }
+
+  // detect BED file version changes
   if (this.bed_file_db_version != null) {
-    this.bed_file_db_version.addEventListener('change', function() {
+    me.bed_file_db_version.addEventListener('change', function() {
+      // Save the new BED file version and sequence_id in hidden fields for BACK and REFRESH.
+      document.getElementById(me.bed_file_input.name + "_selected_db_version").value = me.bed_file_db_version.selectedIndex;
+      var sequence_id = JSON.parse(me.bed_file_db_version.options[me.bed_file_db_version.selectedIndex].getAttribute("data-sequences"))['DNA'].id;
+      document.getElementById(me.bed_file_input.name + "_selected_db_sequence_id").value = sequence_id;
+      // Validate the BED file.
       me.bed_file_validate();
-    },false);
+    }, false);
   }
-  // detect db changes
+
+  // detect BED file changes
+  if (typeof this.bed_file_input !== "undefined") {
+    this.bed_file_input.addEventListener('change', function() {
+      me.bed_file_validate();
+    }, false);
+  }
+
+  //
+  // SEQUENCE DATABASES 
+  //
+
+  // detect DB listing changes
   if (this.db_listing != null) {
     this.db_listing.addEventListener('change', function() {
-      me._load_versions(me.db_listing.value);
+      // Save the DB listing in a hidden field for BACK and REFRESH.
+      document.getElementById(me.file_input.name + "_selected_db_listing").value = me.db_listing.selectedIndex;
+      // Reset the DB version to 0 and save in a hidden field.
+      me.db_version.selectedIndex = document.getElementById(me.file_input.name + "_selected_db_version").value = 0;
+      // Reload the dynamic menus starting with versions and validate the file.
+      me._load_db_versions(me.db_listing.value);
     }, false);
   }
+
+  // detect DB version changes
   if (this.db_version != null) {
-    this.db_version.addEventListener('change', function() {
+    me.db_version.addEventListener('change', function() {
+      // Save the DB version in a hidden field for BACK and REFRESH.
+      document.getElementById(me.file_input.name + "_selected_db_version").value = me.db_version.selectedIndex;
+      // Validate the selected file.
       me._update_db_alphabets();
       me._load_priors();
-    },false);
+      me.file_validate();
+    }, false);
   }
+
   // detect form resets and reset properly
   if (this.source.form != null) {
     this.source.form.addEventListener("reset", function() {
@@ -652,7 +701,7 @@ var SequenceInput = function(container, options) {
       }, 50);
     }, false);
   }
-};
+}; // SequenceInput
 
 /******************************************************************************
  *
@@ -691,7 +740,18 @@ SequenceInput.prototype.set_expected_alphabet = function(alphabet) {
  ******************************************************************************/
 SequenceInput.prototype.check = function(restrict_alphabets) {
   "use strict";
-  var source, id, exists, handler, summary, alphabet;
+  var source, id, exists, handler, summary;
+
+  // Check the custom sequence alphabet.
+  try {
+    if (alphabet.cust_error) {
+      alert("Please correct errors in the custom sequence alphabet.");
+      return false;
+    } 
+  } catch { 
+    // ignore undefined alphabet
+  }
+
   // find out what source we're using
   source = this.source.value;
   if (source == "noseq") return true;
@@ -775,9 +835,8 @@ SequenceInput.prototype.changed = function() {
 };
 
 /******************************************************************************
- *
+// Reset the fields to a consistent state including hidden fields.
  ******************************************************************************/
-// reset the fields to a consistant state
 SequenceInput.prototype.reset = function() {
   "use strict";
   var i, opt;
@@ -799,8 +858,17 @@ SequenceInput.prototype.reset = function() {
     opt = this.source.options[i];
     opt.selected = opt.defaultSelected;
   }
+
+  // Reset the listing and version hidden fields to 0.
+  if (typeof this.bed_file_input != "undefined") {
+    document.getElementById(this.bed_file_input.name + "_selected_db_listing").value = 0;
+    document.getElementById(this.bed_file_input.name + "_selected_db_version").value = 0;
+  }
+  document.getElementById(this.file_input.name + "_selected_db_listing").value = 0;
+  document.getElementById(this.file_input.name + "_selected_db_version").value = 0;
+
   this._source_update();
-};
+}; // SequenceInput.prototype.reset
 
 /******************************************************************************
  *
@@ -856,7 +924,7 @@ SequenceInput.prototype._show_alph_name = function() {
 /******************************************************************************
  *
  ******************************************************************************/
-SequenceInput.prototype._source_update = function() {
+SequenceInput.prototype._source_update = function(is_source_change) {
   "use strict";
   var source, opt, id, i;
   if (this.prior_filter != null && this.prior_filter.checked &&
@@ -878,14 +946,25 @@ SequenceInput.prototype._source_update = function() {
   if (/^\d+$/.test(source)) {
     id = parseInt(source, 10);
     source = "db";
+    // Save the DB category in a hidden field for BACK and REFRESH.
+    document.getElementById(this.file_input.name + "_selected_db_category").value = id;
+    if (is_source_change) {
+      // Set the DB listing and version to 0 and save in hidden fields.
+      this.db_listing.selectedIndex = 0;
+      document.getElementById(this.file_input.name + "_selected_db_listing").value = 0;
+      this.db_version.selectedIndex = 0;
+      document.getElementById(this.file_input.name + "_selected_db_version").value = 0;
+    }
   }
+
   substitute_classes(this.container, ["noseq", "text", "file", "bedfile", "embed", "db"], [source]);
   for (i = 0; i < this.submittables.length; i++) {
-    if(this.submittables[i]) {
+    if (this.submittables[i]) {
       this.submittables[i].disabled = true;
     }
   }
   if (this.parser) this.parser.cancel();
+
   if (source == "text") {
     this.text_area.disabled = false;
     this.text_validate();
@@ -894,17 +973,15 @@ SequenceInput.prototype._source_update = function() {
     this.file_validate();
   } else if (source == "bedfile") {
     this.bed_file_input.disabled = false;
-    this._bed_file_load_listings();
-    this.bed_file_validate();
+    this._load_bed_file_db_listings();
   } else if (source == "db") {
-    // the db hidden inputs will be enabled by the _load_listings command
-    this._load_listings(id);
+    this._load_db_listings(id);
   } else if (source == "embed") {
     this.embed_name.disabled = false;
     this.embed_data.disabled = false;
   }
   this._fire_sequences_checked_event();
-};
+}; // SequenceInput.prototype._source_update
 
 /******************************************************************************
  *
@@ -970,6 +1047,7 @@ SequenceInput.prototype.text_update = function() {
  ******************************************************************************/
 SequenceInput.prototype.file_validate = function() {
   var file;
+
   if (this.parser) this.parser.cancel();
   if (!(file = this.file_input.files[0])) {
     this.file_dbh.clear_indicators();
@@ -994,16 +1072,14 @@ SequenceInput.prototype.bed_file_validate = function() {
     return;
   }
   this.bed_file_dbh.configure(this.options);
-  version_opt = this.bed_file_db_version.options[this.bed_file_db_version.selectedIndex];
-  sequences = (version_opt != null ? JSON.parse(version_opt.getAttribute("data-sequences")) : {});
-  alph = this.alph_info.innerText;
-  if (sequences != null) {
-    sequence_id = sequences[alph].id;
-    sequence_index = load_sequence_index(sequence_id);
-    this.parser = new BedChecker(this.bed_file_dbh);
-    this.parser.process_file(file, sequence_index);
-  }
-};
+  // Restore the saved version for REFRESH and BACK.
+  this.bed_file_db_version.selectedIndex = document.getElementById(this.bed_file_input.name + "_selected_db_version").value;
+  // Process the BED file.
+  sequence_id = document.getElementById(this.bed_file_input.name + "_selected_db_sequence_id").value;
+  sequence_index = load_sequence_index(sequence_id);
+  this.parser = new BedChecker(this.bed_file_dbh);
+  this.parser.process_file(file, sequence_index, this.bed_file_input.name);
+}; // SequenceInput.prototype.bed_file_validate
 
 /******************************************************************************
  *
@@ -1021,35 +1097,10 @@ SequenceInput.prototype.file_update = function() {
 SequenceInput.prototype.bed_file_update = function() {
   "use strict";
   if (this.source.value == "bedfile") {
-    this.bed_file_validate();
+    this._load_bed_file_db_listings();
   }
 };
 
-/******************************************************************************
- *
- ******************************************************************************/
-SequenceInput.prototype._bed_file_db_category_update = function() {
-  "use strict";
-  if (this.source.value == "bedfile") {
-    this._bed_file_load_listings();
-  }
-};
-
-/******************************************************************************
- *
- ******************************************************************************/
-SequenceInput.prototype._bed_file_db_listings_update = function() {
-  "use strict";
-  this._load_versions();
-};
-
-/******************************************************************************
- *
- ******************************************************************************/
-SequenceInput.prototype._bed_file_db_versions_update = function() {
-  "use strict";
-};
-
 /******************************************************************************
  *
  ******************************************************************************/
@@ -1063,21 +1114,24 @@ SequenceInput.prototype._clear_select = function(list) {
   while (optgroup.childNodes.length > 0) {
     optgroup.removeChild(optgroup.lastChild);
   }
-};
+}; // SequenceInput.prototype._clear_select
 
 /******************************************************************************
- *
+ * Reload the database listings and versions and validate the selected file.
+ * The listing index is set from the hidden field.
  ******************************************************************************/
-SequenceInput.prototype._load_listings = function(category_id) {
+SequenceInput.prototype._load_db_listings = function(category_id) {
   "use strict";
   var request, url, i, me, list, optgroup, selected_listing_id;
   // so we can access in the inner function
   me = this;
+  // Use the selected listing saved in the hidden field.
+  selected_listing_id = document.getElementById(this.file_input.name + "_selected_db_listing").value;
   list = this.db_listing;
-  selected_listing_id = (list.value != null ? parseInt(list.value, 10) : null);
+  //selected_listing_id = (list.value != null ? parseInt(list.value, 10) : null);
   optgroup = list.getElementsByTagName("optgroup")[0];
   this._clear_select(list);
-  // now send the request
+  // Create the request.
   url = "../db/sequences?category=" + category_id + "&alphabets=" + this._xml_alph + "&short=" + this._xml_short;
   request = new XMLHttpRequest();
   request.addEventListener("load", function(evt) {
@@ -1102,31 +1156,38 @@ SequenceInput.prototype._load_listings = function(category_id) {
     }
     // re-enable the list
     list.disabled = false;
+    // Reload the versions and validate the file.
     if (list.value) {
-      me._load_versions(parseInt(list.value, 10));
+      // Restore the selected listing from the hidden field.
+      me.db_listing.selectedIndex = document.getElementById(me.file_input.name + "_selected_db_listing").value;
+      // Load the version dynamic menu and validate the file.
+      me._load_db_versions();
     }
   }, false);
   request.open("GET", url, true);
   request.send();
-};
+}; // SequenceInput.prototype._load_db_listings
 
 /******************************************************************************
- *
+ * Reload the BED file listings and versions and validate the BED file.
+ * The listing index is set from the hidden field.
  ******************************************************************************/
-SequenceInput.prototype._bed_file_load_listings = function() {
+SequenceInput.prototype._load_bed_file_db_listings = function() {
   "use strict";
   var request, url, i, id, me, bed_file_db_category, list, optgroup, selected_listing_id;
   // so we can access in the inner function
   me = this;
+  // Get the category ID.
   bed_file_db_category = this.bed_file_db_category.value;
   if (/^\d+$/.test(bed_file_db_category)) {
     id = parseInt(bed_file_db_category, 10);
   }
+  // Use the selected listing saved in the hidden field.
+  selected_listing_id = document.getElementById(this.bed_file_input.name + "_selected_db_listing").value;
   list = this.bed_file_db_listing;
-  selected_listing_id = (list.value != null ? parseInt(list.value, 10) : null);
   optgroup = list.getElementsByTagName("optgroup")[0];
   this._clear_select(list);
-  // now send the request
+  // Create the request.
   url = "../db/sequences?category=" + id + "&alphabets=" + this._xml_alph + "&short=" + this._xml_short;
   request = new XMLHttpRequest();
   request.addEventListener("load", function(evt) {
@@ -1144,32 +1205,36 @@ SequenceInput.prototype._bed_file_load_listings = function() {
     }
     // re-enable the list
     list.disabled = false;
+    // Reload the versions and validate the BED file.
     if (list.value) {
-      me._load_bed_file_db_versions(parseInt(list.value, 10));
+      // Restore the selected listing from the hidden field.
+      me.bed_file_db_listing.selectedIndex = document.getElementById(me.bed_file_input.name + "_selected_db_listing").value;
+      // Load the version dynamic menu and validate BED file.
+      me._load_bed_file_db_versions();
     }
   }, false);
   request.open("GET", url, true);
   request.send();
-};
+}; // SequenceInput.prototype._load_bed_file_db_listings
 
 /******************************************************************************
  *
  ******************************************************************************/
-SequenceInput.prototype._load_versions = function(listing_id) {
+SequenceInput.prototype._load_db_versions = function() {
   "use strict";
-  var me, request, url, i, list, optgroup, selected_version_id;
+  var me, request, url, list, optgroup, listing_id;
   // so we can access in the inner function
   me = this;
+  listing_id = this.db_listing.options[this.db_listing.selectedIndex].value;
   list = this.db_version;
-  selected_version_id = (list.value != null ? parseInt(list.value, 10) : null);
   optgroup = list.getElementsByTagName("optgroup")[0];
   this._clear_select(list);
-  // now send the request
   url = "../db/sequences?listing=" + listing_id + "&alphabets=" + this._xml_alph + "&short=" + this._xml_short;
   request = new XMLHttpRequest();
   request.addEventListener("load", function(evt) {
-    var data, version, i, j, hasPriors, opt;
+    var data, version, i, j, hasPriors, opt, selected_version_id;
     data = JSON.parse(request.responseText);
+    selected_version_id = document.getElementById(me.file_input.name + "_selected_db_version").value;
     // ensure the list is empty
     me._clear_select(list);
     // add the other options
@@ -1196,33 +1261,38 @@ SequenceInput.prototype._load_versions = function(listing_id) {
       opt = list.querySelector("option:not(.no_priors)");
       if (opt != null) list.selectedIndex = opt.index;
     }
+    // Restore selected version from hidden fields.
+    me.db_version.selectedIndex = document.getElementById(me.file_input.name + "_selected_db_version").value;
     // re-enable the list
     list.disabled = false;
     me._update_db_alphabets();
     me._load_priors();
+    // Validate the file now that all dynamic menus are loaded.
+    me.file_validate();
   }, false);
   request.open("GET", url, true);
   request.send();
-};
+}; // SequenceInput.prototype._load_db_versions
 
 /******************************************************************************
  *
  ******************************************************************************/
-SequenceInput.prototype._load_bed_file_db_versions = function(listing_id) {
+SequenceInput.prototype._load_bed_file_db_versions = function() {
   "use strict";
-  var me, request, url, i, list, optgroup, selected_version_id;
+  var me, request, url, list, optgroup, listing_id;
   // so we can access in the inner function
   me = this;
   list = this.bed_file_db_version;
-  selected_version_id = (list.value != null ? parseInt(list.value, 10) : null);
   optgroup = list.getElementsByTagName("optgroup")[0];
   this._clear_select(list);
-  // now send the request
+  // create the request
+  listing_id = this.bed_file_db_listing.options[this.bed_file_db_listing.selectedIndex].value;
   url = "../db/sequences?listing=" + listing_id + "&alphabets=" + this._xml_alph + "&short=" + this._xml_short;
   request = new XMLHttpRequest();
   request.addEventListener("load", function(evt) {
-    var data, version, i, j, hasPriors, opt;
+    var data, version, i, j, hasPriors, opt, selected_version_id;
     data = JSON.parse(request.responseText);
+    selected_version_id = document.getElementById(me.bed_file_input.name + "_selected_db_version").value;
     // ensure the list is empty
     me._clear_select(list);
     // add the other options
@@ -1245,11 +1315,20 @@ SequenceInput.prototype._load_bed_file_db_versions = function(listing_id) {
     }
     // re-enable the list
     list.disabled = false;
+    // Restore the selected version from the hidden field.
+    me.bed_file_db_version.selectedIndex = document.getElementById(me.bed_file_input.name + "_selected_db_version").value;
+    // Save the selected sequence_id in a hidden field for BACK and REFRESH.
+    var sequence_id = JSON.parse(me.bed_file_db_version.options[me.bed_file_db_version.selectedIndex].getAttribute("data-sequences"))['DNA'].id;
+    document.getElementById(me.bed_file_input.name + "_selected_db_sequence_id").value = sequence_id;
+    // Validate the BED file now that all dynamic menus are loaded.
     me._update_bed_file_db_alphabets();
+    me.bed_file_validate();
   }, false);
+
+  // execute the request
   request.open("GET", url, true);
   request.send();
-};
+}; // SequenceInput.prototype._load_bed_file_db_versions
 
 /******************************************************************************
  *
