@@ -368,6 +368,7 @@ FastaChecker.prototype.process_blob = function (blob, offset, chunk_size) {
   if (offset === 0) {
     if (typeof this.handler.begin == "function") {
       this.handler.begin(
+          blob.name,
           blob.size, 
           function () { return me.guess_alphabets(); }
       );
@@ -451,7 +452,6 @@ FastaChecker.prototype.guess_alphabets = function() {
   return AlphabetUtil.guess(this.alphabets, this.file_symbols, this.file_counts, true);
 };
 
-
 //******************************************************************************
 // Fasta Handler
 //******************************************************************************
@@ -465,10 +465,10 @@ FastaHandler.prototype.configure = function (options) {
   var alphabets, alphabet_name;
   if (typeof options != "object" || options == null) options = {};
   // configure file size
-  if (typeof options.file_max == "number") {
-    this.max_file_size = options.file_max;
+  if (typeof options.max_file_size == "number") {
+    this.max_file_size = options.max_file_size;
   } else {
-    this.max_file_size = null; // 20 MB
+    this.max_file_size = null;
   }
   // enable MEME weights extension?
   if (typeof options.weights == "boolean") {
@@ -500,7 +500,13 @@ FastaHandler.prototype.configure = function (options) {
   } else {
     this.only_uppercase = false;
   }
-  // specify a maximum name length?
+  // specify a maximum file name length?
+  if (typeof options.max_file_name_len == "number" && options.max_file_name_len >= 1) {
+    this.max_file_name_length = options.max_file_name_len;
+  } else {
+    this.max_file_name_length = null;
+  }
+  // specify a maximum (sequence) name length?
   if (typeof options.max_name_len == "number" && options.max_name_len >= 1) {
     this.max_name_length = options.max_name_len;
   } else {
@@ -601,9 +607,14 @@ FastaHandler.prototype.summary = function () {
     if (is_error) error = true;
     else warning = true;
   };
+  // file name length error
+  if (this.max_file_name_length != null && this.file_name != null && this.file_name.length > this.max_file_name_length) {
+    add(true, "Sequence file name is too long: " + this.file_name.length + " > " + this.max_file_name_length + ".");
+  }
   // file size warning
   if (this.max_file_size != null && this.file_size > this.max_file_size) {
-    add(false, "Large file. ", ["File is " + (Math.round(this.file_size / (1<<20) )) + "MB"] + ". ")
+    add(true, "FASTA File is too large. ", ["File is over " + (Math.trunc(this.file_size/1000000)) + "MB but should be no larger than " +
+      (this.max_file_size/1000000) + "MB."])
   }
   // encoding or format error
   help = " - re-save as plain text; either Unicode UTF-8 (no Byte Order Mark) or ASCII";
@@ -795,13 +806,13 @@ FastaHandler.prototype.summary = function () {
   // report long sequence identifiers
   if (this.long_name.faults() > 0) {
     if (this.long_name.faults() == 1) {
-      reason = "Found a sequence with a long identifier on line ";
+      reason = "Found a sequence with an identifier longer than " + this.max_name_length + " characters on line ";
     } else {
       reason = "Found " + this.long_name.faults() + 
-        " sequences with long identifiers on lines. ";
+        " sequences with identifiers longer than " + this.max_name_length + " characters on lines ";
     }
     reason += this.long_name.lines_str() + ". ";
-    add(false, "Long sequence identifiers may cause problems. ", [reason]);
+    add(true, "Bad sequence identifier(s). ", [reason]);
 
   }
   // report long sequence descriptions
@@ -843,9 +854,10 @@ FastaHandler.prototype.progress = function (fraction) {
 };
 
 // Reading of the file has begun
-FastaHandler.prototype.begin = function (file_size, fn_alphabets) {
+FastaHandler.prototype.begin = function (file_name, file_size, fn_alphabets) {
   "use strict";
   this.reset();
+  this.file_name = file_name;
   this.file_size = file_size;
   this.fn_alphabets = fn_alphabets;
   this.updated = true;
