@@ -513,7 +513,9 @@ function on_load() {
   $("filter_enable").addEventListener('change', updateFilterDisplay, false);
   $("filter_field").addEventListener('change', on_filter_field_change, false);
   window.addEventListener('pageshow', on_pageshow, false);
-  fix_reset();
+  //fix_reset();
+  on_alg_change(1);
+  updateFilterMenu(); 		// update the filter menu from the first PTM file
 }
 
 // add a load
