@@ -168,7 +168,6 @@ MotifUtils.as_pspm = function(motif) {
   return new Pspm(motif.pwm, motif.id, 0, 0, motif.nsites, motif.evalue, null, motif.alt);
 };
 
-
 var HtmlMotifParser = function (handler) {
   "use strict";
   var tag_names, i;
@@ -683,8 +682,6 @@ HtmlMotifParser.prototype._html_json = function (chunk) {
   return chunk.length;
 };
 
-
-
 HtmlMotifParser.prototype._html_hidden_input = function (name, value) {
   "use strict";
   var parts, freqs, letters, i, j, sum, lines, index, is_pssm, keyvals, key, num, matrix;
@@ -1026,6 +1023,12 @@ HtmlMotifParser.prototype._html_data = function (data) {
   for (i = 0; i < motifs.length; i++) {
     motif = motifs[i];
     // TODO test motif
+    if (typeof this.handler.meta == "function") {
+      this.handler.meta({
+	"motif_id": motif.id,
+        "motif_index": i+1
+      });
+    }
     if (typeof this.handler.motif == "function") this.handler.motif(motif);
     this.rating = 10;
   }
@@ -1271,8 +1274,13 @@ TextMotifParser.prototype._in_freqs = function (line) {
 
 TextMotifParser.prototype._enqueue_motif = function() {
   "use strict";
-  var i, uniform;
   if (this.motif_id == null) return;
+  // check id length
+  if (typeof this.handler.meta == "function") {
+    this.handler.meta({
+      "motif_id": this.motif_id
+    });
+  }
   if (!this.sent_meta) {
     // generate missing fields
     if (this.alphabet == null) throw new Error("Expected to have worked out the alphabet by now!");
@@ -1595,10 +1603,17 @@ XmlMotifParser.prototype._meme_alphabet_matrix = function (am_node, id_order, is
   return matrix;
 };
 
-XmlMotifParser.prototype._meme_motif = function (motif_node, symbol_ids) {
+XmlMotifParser.prototype._meme_motif = function (motif_index, motif_node, symbol_ids) {
   "use strict";
   // read the name
   var id = motif_node.getAttribute("name");
+  // check id length
+  if (typeof this.handler.meta == "function") {
+    this.handler.meta({
+      "motif_id": id,
+      "motif_index": motif_index
+    });
+  }
   if (id == null) throw new MotifError("MEME XML motif does not have a name attribute.");
   var alt = "MEME";
   // read the width
@@ -1682,7 +1697,8 @@ XmlMotifParser.prototype.process_meme_doc = function (doc) {
         alph_parser.parse_symbol(letter_symbol, {
           "aliases": letter_aliases, "name": letter_name, "colour": letter_colour,
           "complement": letter_complement, "comprise": letter_equals
-        });
+          }, "--XML motif--"
+        );
       }
       var alph_data = alph_parser.parse_done();
       alphabet = new Alphabet(alph_data);
@@ -1744,7 +1760,7 @@ XmlMotifParser.prototype.process_meme_doc = function (doc) {
   // now iterate over motifs
   var motifs = doc.querySelectorAll("MEME > motifs > motif");
   for (i = 0; i < motifs.length; i++) {
-    this._meme_motif(motifs[i], symbol_ids);
+    this._meme_motif(i+1, motifs[i], symbol_ids);
   }
 };
 
@@ -1798,12 +1814,19 @@ XmlMotifParser.prototype._streme_probability_array = function (probs_node, alph_
   return array;
 };
 
-XmlMotifParser.prototype._dreme_motif = function (motif_node, alph_ids) {
+XmlMotifParser.prototype._dreme_motif = function (motif_index, motif_node, alph_ids) {
   "use strict";
   var i;
   // read the id
   var id = motif_node.getAttribute("seq");
   if (id == null) throw new MotifError("DREME XML motif seq attribute is missing.");
+  // check id length
+  if (typeof this.handler.meta == "function") {
+    this.handler.meta({
+      "motif_id": id,
+      "motif_index": motif_index
+    });
+  }
   var alt = "DREME";
   // read the length
   var len = motif_node.getAttribute("length");
@@ -1844,12 +1867,19 @@ XmlMotifParser.prototype._dreme_motif = function (motif_node, alph_ids) {
   if (this.rating < 10) this.rating = 10;
 };
 
-XmlMotifParser.prototype._streme_motif = function (motif_node, alph_ids) {
+XmlMotifParser.prototype._streme_motif = function (motif_index, motif_node, alph_ids) {
   "use strict";
   var i;
   // read the id
   var id = motif_node.getAttribute("id");
   if (id == null) throw new MotifError("STREME XML motif id attribute is missing.");
+  // check id length
+  if (typeof this.handler.meta == "function") {
+    this.handler.meta({
+      "motif_id": id,
+      "motif_index": motif_index
+    });
+  }
   var alt = "STREME";
   // read the length
   var len = motif_node.getAttribute("width");
@@ -1926,7 +1956,8 @@ XmlMotifParser.prototype.process_dreme_doc = function (doc) {
         alph_parser.parse_symbol(letter_symbol, {
           "aliases": letter_aliases, "name": letter_name, "colour": letter_colour,
           "complement": letter_complement, "comprise": letter_equals
-        });
+          }, "--DREME motif--"
+        );
       }
       var alph_data = alph_parser.parse_done();
       alphabet = new Alphabet(alph_data);
@@ -1972,7 +2003,7 @@ XmlMotifParser.prototype.process_dreme_doc = function (doc) {
   // now iterate over motifs
   var motifs = doc.querySelectorAll("dreme  > motifs > motif");
   for (i = 0; i < motifs.length; i++) {
-    this._dreme_motif(motifs[i], alphabet_ids);
+    this._dreme_motif(i+1, motifs[i], alphabet_ids);
   }
 };
 
@@ -2012,7 +2043,8 @@ XmlMotifParser.prototype.process_streme_doc = function (doc) {
         alph_parser.parse_symbol(letter_symbol, {
           "aliases": letter_aliases, "name": letter_name, "colour": letter_colour,
           "complement": letter_complement, "comprise": letter_equals
-        });
+          }, "--STREME motif--"
+        );
       }
       var alph_data = alph_parser.parse_done();
       alphabet = new Alphabet(alph_data);
@@ -2074,7 +2106,7 @@ XmlMotifParser.prototype.process_streme_doc = function (doc) {
   // now iterate over motifs
   var motifs = doc.querySelectorAll("STREME > motifs > motif");
   for (i = 0; i < motifs.length; i++) {
-    this._streme_motif(motifs[i], alphabet_ids);
+    this._streme_motif(i+1, motifs[i], alphabet_ids);
   }
 };
 
@@ -2213,7 +2245,7 @@ MotifParser.prototype.process_blob = function (blob, offset, chunk_size) {
   if (typeof chunk_size === "undefined") chunk_size = 1 << 12;
   // update the progress
   if (offset === 0 && typeof this.handler.begin == "function")
-    this.handler.begin(blob.size);
+    this.handler.begin(blob.size, blob.name);
   if (typeof this.handler.progress == "function")
     this.handler.progress(offset / blob.size);
   // setup the reader
@@ -2221,7 +2253,7 @@ MotifParser.prototype.process_blob = function (blob, offset, chunk_size) {
   reader = new FileReader();
   reader.onload = function(evt) {
     "use strict";
-    var chunk, i, file_name, format, message;
+    var chunk, i, format, message;
     if (me.give_up) return;
     // process the loaded chunk
     chunk = new Uint8Array(reader.result);
