@@ -27,6 +27,9 @@ function options_reset() {
   $("closest_tss").checked = true;
 }
 
+function on_ch_loci() {
+}
+
 function fix_reset() {
   // Make sure "Hidden Modifications" gets turned off on form reset.
   var i, more_opts = document.getElementsByClassName("more_opts");
@@ -50,6 +53,7 @@ function on_pageshow() {
 }
 
 function on_load() {
+  $("loci").addEventListener("loci_checked", on_ch_loci, false);
   // add listener to the form to check the fields before submit
   $("tgene_form").addEventListener("submit", on_form_submit, false);
   $("tgene_form").addEventListener("reset", on_form_reset, false);
