@@ -187,6 +187,36 @@ public class DBList {
     return count;
   }
 
+  // Check that tblSequenceFile contains the fileSeqIndex column.
+  public void testIndexFileColumn() throws SQLException {
+    Connection connection = null;
+    ResultSet rs = null;
+    try {
+      connection = ds.getConnection();
+      Statement statement = connection.createStatement();
+      rs = statement.executeQuery(TEST_INDEX_FILE_COLUMN);
+      String schema = rs.getString(1);
+      if (!schema.contains("fileSeqIndex")) {
+	throw new SQLException("\n\tSomething is wrong with your FASTA database: " + 
+	  "table 'tblSequenceFile' is missing the 'fileSeqIndex' column.");
+      }
+      statement.close(); statement = null;
+      connection.close(); connection = null;
+      rs.close(); rs = null;
+    } finally {
+      if (rs != null) {
+        try {
+          rs.close();
+        } catch (SQLException e) { /* ignore */ }
+      }
+      if (connection != null) {
+        try {
+          connection.close();
+        } catch (SQLException e) { /* ignore */ }
+      }
+    }
+  }
+
   protected PreparedStatement prepareListingsQuery(Connection conn, long categoryId,
       boolean shortOnly, EnumSet<AlphStd> allowedAlphabets) throws SQLException {
     PreparedStatement ps = conn.prepareStatement(SELECT_LISTINGS_OF_CATEGORY);
