@@ -235,7 +235,7 @@ public class Centrimo extends SubmitJob<Centrimo.Data> {
     comparative = new ComponentSequences(context, tmplMain.getSubtemplate("comparative"));
     background = new ComponentBfile(context, tmplMain.getSubtemplate("bfile"));
     jobDetails = new ComponentJobDetails(cache);
-    advBtn = new ComponentAdvancedOptions(cache);
+    advBtn = new ComponentAdvancedOptions(cache, tmplMain.getSubtemplate("advanced_options"));
     submitReset = new ComponentSubmitReset(cache, jobTable.getCount(), jobTable.getDuration());
     footer = new ComponentFooter(cache, msp);
   }
