@@ -187,7 +187,7 @@ public class Fimo extends SubmitJob<Fimo.Data> {
         sequences.getHelp(), jobDetails.getHelp(), advancedOptions.getHelp(),
         submitReset.getHelp(), footer.getHelp()});
     main.set("header", header.getComponent());
-    main.set("motifs", motifs.getComponent(request.getParameter("motifs_embed")));
+    main.set("motifs", motifs.getComponent(request.getParameter("motifs_embed"), request.getParameter("motifs_name")));
     main.set("sequences", sequences.getComponent());
     main.set("bfile", background.getComponent());
     main.set("job_details", jobDetails.getComponent());
