@@ -202,7 +202,7 @@ public class Mast extends SubmitJob<Mast.Data> {
         sequences.getHelp(), jobDetails.getHelp(), advBtn.getHelp(),
         submitReset.getHelp(), footer.getHelp()});
     main.set("header", header.getComponent());
-    main.set("motifs", motifs.getComponent(request.getParameter("motifs_embed")));
+    main.set("motifs", motifs.getComponent(request.getParameter("motifs_embed"), request.getParameter("motifs_name")));
     main.set("sequences", sequences.getComponent());
     main.set("job_details", jobDetails.getComponent());
     main.set("advanced_options", advBtn.getComponent());
