@@ -146,7 +146,7 @@ public class Sea extends SubmitJob<Sea.Data> {
     motifs = new ComponentMotifs(context, tmplMain.getSubtemplate("motifs"));
     background = new ComponentBfile(context, tmplMain.getSubtemplate("bfile"));
     jobDetails = new ComponentJobDetails(cache);
-    advancedOptions = new ComponentAdvancedOptions(cache);
+    advancedOptions = new ComponentAdvancedOptions(cache, tmplMain.getSubtemplate("advanced_options"));
     submitReset = new ComponentSubmitReset(cache, jobTable.getCount(), jobTable.getDuration());
     footer = new ComponentFooter(cache, msp);
   }
