@@ -415,10 +415,16 @@ public abstract class SubmitJob<E extends SubmitJob.JobData> extends HttpServlet
 
   private String describeBackground(Background background) {
     switch (background.getSource()) {
+      case CONTROL:
+        return "A background based on the control sequences.";
+      case NRDB:
+        return "A background based on frequencies in the NRDB.";
       case UNIFORM:
         return "A uniform background.";
       case MEME:
         return "The background specified in the motif input.";
+      case DEFAULT:
+        return "The default background.";
       case FILE:
       {
         NamedFileDataSource file = background.getBfile();
