@@ -40,6 +40,8 @@ public class ComponentSequences extends PageComponent {
   private boolean shortOnly; // only short databases
   private String prefix;
   private String fieldName; // for feedback
+  private Integer maxFileSize;
+  private Integer maxFileNameLen;
   private HTMLTemplate title;
   private HTMLTemplate subtitle;
   private boolean disableBed;
@@ -141,10 +143,15 @@ public class ComponentSequences extends PageComponent {
 
   public ComponentSequences(ServletContext context, HTMLTemplate info) throws ServletException {
     this.context = context;
+    // getText and getInfo values can be OVERRIDDEN in the servlet template (e.g., streme.tmpl)
+    // by placing tags inside the <!--{sequences}--> subtemplate such as;
+    //       <!--{max_file_size}-->1000<!--{/max_file_size}-->
     HTMLTemplateCache cache = (HTMLTemplateCache)context.getAttribute(CACHE_KEY);
     tmplSequences = cache.loadAndCache("/WEB-INF/templates/component_sequences.tmpl");
     prefix = getText(info, "prefix", "sequences");
     fieldName = getText(info, "description", "sequences");
+    maxFileSize = getInt(info, "max_file_size", 80000000);
+    maxFileNameLen = getInt(info, "max_file_name_len", 100);
     registerFn = getText(info, "register", "nop");
     title = getTemplate(info, "title", null);
     subtitle = getTemplate(info, "subtitle", null);
@@ -268,6 +275,8 @@ public class ComponentSequences extends PageComponent {
     try {
       jsonWr.start();
       jsonWr.property("field", fieldName);
+      jsonWr.property("max_file_size", maxFileSize);
+      jsonWr.property("max_file_name_len", maxFileNameLen);
       jsonWr.property("alph_type", type.name());
       jsonWr.property("short_only", shortOnly);
       jsonWr.property("weights", weights);
@@ -352,7 +361,8 @@ public class ComponentSequences extends PageComponent {
     }
     SequenceDB dbFile;
     try {
-      Set<AlphStd> dbAlphs = type.getStandardAlphabets();
+      // BED files may only be used with DNA so set allowed alphabets to just DNA.
+      Set<AlphStd> dbAlphs = EnumSet.of(AlphStd.DNA);
       dbFile = db.getSequenceFile(listingId, edition, dbAlphs);
     } catch (SQLException e) {
       throw new ServletException(e);
