@@ -291,7 +291,7 @@ public class FtpFileListUpdater extends SequenceUpdater {
         String a_verb = (navailable_genomes == 1) ? " is " : " are ";
         String m_verb = (nmissing_genomes == 1) ? " is " : " are ";
 	System.out.println("\nThere" + a_verb + navailable_genomes + " available sequence file(s) and " + 
-          (navailable_genomes - nhave_genomes) + m_verb + "missing.\n*******");
+          (navailable_genomes - nhave_genomes) + m_verb + "missing or out of date.\n*******");
       }
     } finally {
       if (reader != null) {
@@ -501,7 +501,13 @@ public class FtpFileListUpdater extends SequenceUpdater {
 
     @Override
     public long getSequenceEdition() {
-      return timestamp.getTimeInMillis();
+      //return timestamp.getTimeInMillis();
+      Date date = new Date(System.currentTimeMillis());
+      Calendar calendar = Calendar.getInstance();
+      calendar.setTime(date);
+      long edition = calendar.get(Calendar.DATE) + (100 * calendar.get(Calendar.MONTH)) + (100 * 100 * calendar.get(Calendar.YEAR));
+      System.out.println(entry.name + " (" + this.alphabet + ") edition: " + edition);
+      return(edition);
     }
 
     @Override
