@@ -28,8 +28,7 @@ import java.util.zip.ZipEntry;
 import java.util.zip.ZipFile;
 import java.util.zip.ZipInputStream;
 
-import static au.edu.uq.imb.memesuite.db.SQL.*;
-import static au.edu.uq.imb.memesuite.db.SQL.INSERT_SEQUENCE_FILE;
+//import static au.edu.uq.imb.memesuite.db.SQL.*;
 
 /**
  * Processes a downloaded sequence file to decompress it and generate statistics.
@@ -39,6 +38,7 @@ public abstract class SequenceProcessor implements Callable<Void> {
   private ReadWriteLock dbLock;
   private File binDir;
   private File dbDir;
+  private File dbTarget;
   private MultiSourceStatus multiStatus;
   private Progress progress;
 
@@ -415,10 +415,10 @@ public abstract class SequenceProcessor implements Callable<Void> {
     }
   }
 
-  protected boolean unpackSequences(Source genome) throws IOException, InterruptedException {
-    logger.log(Level.INFO, "Unpacking sequences for " + genome);
+  protected boolean unpackSequences(Source genome, File dbTarget) throws IOException, InterruptedException {
+    logger.log(Level.INFO, "Unpacking sequences for " + genome + " into " + dbTarget);
     progress.setTask("Unpacking sequences for " + genome, 0, -1);
-    File sequenceFile = new File(dbDir, genome.getNamePrefix() + ext(genome.guessAlphabet()));
+    File sequenceFile = new File(dbTarget, genome.getNamePrefix() + ext(genome.guessAlphabet()));
     OutputStream sequenceOut = null;
     try {
       sequenceOut = new BufferedOutputStream(new FileOutputStream(sequenceFile));
@@ -516,18 +516,18 @@ public abstract class SequenceProcessor implements Callable<Void> {
     return summaryMonitor.getSummary();
   }
 
-  protected void processSequences(Source genome) throws IOException, InterruptedException {
+  protected void processSequences(Source genome, File dbTarget) throws IOException, InterruptedException {
     logger.log(Level.INFO, "Calculating background and statistics of the " +
         "sequences in the file \"" + genome.getSequenceFile() + "\"");
     progress.setTask("Calculating background and statistics for " + genome, 0, genome.getSequenceFile().length());
     String seqs = genome.getSequenceFile().getName();
-    File bgFile = new File(dbDir, seqs + ".bfile");
+    File bgFile = new File(dbTarget, seqs + ".bfile");
     FastaGetMarkovSummary summary = generateBackground(binDir, genome.guessAlphabet(), genome.getSequenceFile(), bgFile, progress);
     genome.setBgFile(bgFile);
     genome.setStats(summary.count, summary.minLen, summary.maxLen, summary.avgLen, 0.0, summary.totalLen);
   }
 
-  protected SequenceKeys recordSequences(Source genome) throws SQLException {
+  protected SequenceKeys recordSequences(Source genome, File dbTarget, String dbSubdir) throws SQLException {
     Long categoryId = null, listingId = null;
     long fileId;
     logger.log(Level.INFO, "Creating database record for " + genome);
@@ -540,7 +540,7 @@ public abstract class SequenceProcessor implements Callable<Void> {
       connection = dataSource.getConnection();
       connection.setAutoCommit(false);
       // get or create the category
-      ps = connection.prepareStatement(SELECT_CATEGORY_BY_NAME);
+      ps = connection.prepareStatement(SQL.SELECT_CATEGORY_BY_NAME);
       ps.setString(1, genome.getCategoryName());
       rs = ps.executeQuery();
       if (rs.next()) {
@@ -549,7 +549,7 @@ public abstract class SequenceProcessor implements Callable<Void> {
       rs.close();
       ps.close();
       if (categoryId == null) {
-        ps = connection.prepareStatement(INSERT_CATEGORY);
+        ps = connection.prepareStatement(SQL.INSERT_CATEGORY);
         ps.setString(1, genome.getCategoryName());
         ps.executeUpdate();
         rs = ps.getGeneratedKeys();
@@ -559,7 +559,7 @@ public abstract class SequenceProcessor implements Callable<Void> {
         ps.close();
       }
       // get or create the listing
-      ps = connection.prepareStatement(SELECT_LISTING_BY_NAME);
+      ps = connection.prepareStatement(SQL.SELECT_LISTING_BY_NAME);
       ps.setLong(1, categoryId);
       ps.setString(2, genome.getListingName());
       rs = ps.executeQuery();
@@ -569,7 +569,7 @@ public abstract class SequenceProcessor implements Callable<Void> {
       rs.close();
       ps.close();
       if (listingId == null) {
-        ps = connection.prepareStatement(INSERT_LISTING);
+        ps = connection.prepareStatement(SQL.INSERT_LISTING);
         ps.setLong(1, categoryId);
         ps.setString(2, genome.getListingName());
         ps.setString(3, genome.getListingDescription());
@@ -581,15 +581,15 @@ public abstract class SequenceProcessor implements Callable<Void> {
         ps.close();
       }
       // create the sequence file entry
-      ps = connection.prepareStatement(INSERT_SEQUENCE_FILE);
+      ps = connection.prepareStatement(SQL.INSERT_SEQUENCE_FILE);
       ps.setInt(1, genome.getRetrieverId());
       ps.setLong(2, listingId);
       ps.setInt(3, genome.guessAlphabet().toInt());
       ps.setLong(4, genome.getSequenceEdition());
       ps.setString(5, genome.getSequenceVersion());
       ps.setString(6, genome.getSequenceDescription());
-      ps.setString(7, genome.getSequenceFile().getName());
-      ps.setString(8, genome.getBgFile().getName());
+      ps.setString(7, dbSubdir + "/" + genome.getSequenceFile().getName());
+      ps.setString(8, dbSubdir + "/" + genome.getBgFile().getName());
       ps.setLong(9, genome.getSequenceCount());
       ps.setLong(10, genome.getTotalLength());
       ps.setLong(11, genome.getMinLength());
