@@ -47,7 +47,7 @@ public class UCSCGenomeUpdater extends SequenceUpdater {
     DbRegexp = dbRegexp;
     Properties conf = loadConf(UCSCGenomeUpdater.class, dbDir, "UCSCGenomeUpdater.properties");
     scrape = conf.getProperty("scrape", "http://genome.ucsc.edu/FAQ/FAQreleases.html").trim();
-    host = conf.getProperty("host", "hgdownload.soe.ucsc.edu").trim();
+    host = conf.getProperty("host", "hgdownload.cse.ucsc.edu").trim();
     path = conf.getProperty("path", "/goldenPath/").trim();
     ftpLog = conf.getProperty("ftp.log", "").trim();
     categoryName = conf.getProperty(division + "_categoryName", "unknown_categoryName");
@@ -144,6 +144,8 @@ public class UCSCGenomeUpdater extends SequenceUpdater {
           // try to recreate the connection
           if (!loginFtp(ftp, host)) throw new IOException("Unable to login to " + host);
         }
+	// Passive mode FTP doesn't work.
+        ftp.enterLocalActiveMode();
         return determineFtpSource(ftp, genome);
       } catch (IOException e) {
         logger.log(Level.WARNING, "Failed to determine source for " + genome + " attempt " + attempt + " of " + retryCount, e);
